<?php 
/*
Plugin Name: Extender Pro
Version: 1.0.8
Plugin URI: https://cobaltapps.com/downloads/extender-pro-plugin/
Description: The ultimate Theme Framework companion Plugin.
Author: Cobalt Apps
Author URI: https://cobaltapps.com/
License: GPLv2 or later
License URI: http://www.opensource.org/licenses/gpl-license.php
*/

/**
 * @package Extender Pro
 */
 
// Prevent direct access.
if ( ! defined( 'ABSPATH' ) ) exit;

update_option('extender_pro_license_key', 'NULLED-BY-GANJAPARKER'); 
update_option('extender_pro_license_status', 'valid'); 

/**
 * Create a conditional that checks for compatible themes.
 *
 * @since 1.0.0
 * @return a conditional that checks for compatible themes.
 */
function extender_pro_compatible_theme_check() {
	
	$wp_get_theme = wp_get_theme();
	
	$compatible_themes = array(
		'astra' => 'Astra',
		'bb-theme' => 'Beaver Builder Theme',
		'freelancer' => 'Freelancer',
		'generatepress' => 'GeneratePress',
		'genesis' => 'Genesis',
		'oceanwp' => 'OceanWP',
	);
	
	if ( array_key_exists( $wp_get_theme->get( 'Template' ), $compatible_themes ) || in_array( $wp_get_theme->get( 'Name' ), $compatible_themes ) )
		$compatible_theme = true;
	else
		$compatible_theme = false;

	return $compatible_theme;
	
}

if ( false === extender_pro_compatible_theme_check() ) {
	
	add_action( 'admin_notices', 'extender_pro_requires_compatible_theme_notice' );
	
} else {
	
	/**
	 * Define plugin constants.
	 */
	if ( ! defined( 'EXTPRO_DIR' ) )
		define( 'EXTPRO_DIR', plugin_dir_path( __FILE__ ) );
		
	if ( ! defined( 'EXTPRO_URL' ) )
		define( 'EXTPRO_URL', plugin_dir_url( __FILE__ ) );
		
	// Define the Cobalt Apps WP Admin Bar URL constant.
	if ( ! defined( 'CAABM_URL' ) )
		define( 'CAABM_URL', EXTPRO_URL );
		
	define( 'EXTPRO_VERSION', '1.0.8' );
	
	/**
	 * Create a conditional that returns the active theme framework name.
	 * This function is necessary for various code, including early
	 * loading functions, to properly execute.
	 *
	 * @since 1.0.0
	 * @return the active theme framework name.
	 */
	function extender_pro_active_theme_name() {
		
		if ( defined( 'ASTRA_THEME_VERSION' ) )
			$active_theme = 'astra';
		elseif ( defined( 'FL_THEME_VERSION' ) )
			$active_theme = 'bb-theme';
		elseif ( defined( 'FREELANCER_PARENT_THEME_NAME' ) )
			$active_theme = 'freelancer';
		elseif ( defined( 'GENERATE_VERSION' ) )
			$active_theme = 'generatepress';
		elseif ( defined( 'PARENT_THEME_NAME' ) && PARENT_THEME_NAME == 'Genesis' )
			$active_theme = 'genesis';
		elseif ( defined( 'OCEANWP_THEME_VERSION' ) )
			$active_theme = 'oceanwp';
	
		return $active_theme;
		
	}
	
	/**
	 * Sanatize strings of text.
	 *
	 * @since 1.0.0
	 */
	function extender_pro_sanitize_string( $string = '', $underscore = false ) {
		
	    // Lower case everything
	    $string = strtolower( $string );
	    // Make alphaunermic
	    $string = preg_replace( "/[^a-z0-9_\s-]/", "", $string );
	    // Clean multiple dashes or whitespaces
	    $string = preg_replace( "/[\s-]+/", " ", $string );
	    if ( false != $underscore ) {
	    	
		    // Convert whitespaces and dashes to underscore
		    $string = preg_replace( "/[\s-]/", "_", $string );
		    
	    } else {
	    	
		    // Convert whitespaces and underscore to dash
		    $string = preg_replace( "/[\s_]/", "-", $string );
		    
		}
	    return $string;
	    
	}
	
	/**
	 * Build the appropriate full get/update option text.
	 *
	 * @since 1.0.0
	 * @return the appropriate full get/update option text.
	 */
	function extender_pro_theme_option_name( $option ) {
		
		$name = 'extender_pro_' . extender_pro_sanitize_string( extender_pro_active_theme_name(), true ) . '_' . $option;
		
		return $name;
	    
	}
	
	/**
	 * Require options file.
	 */
	require_once( EXTPRO_DIR . 'lib/functions/options.php' );
	
	/**
	 * Require paths file.
	 */
	require_once( EXTPRO_DIR . 'lib/functions/paths.php' );
	
	/**
	 * Create globals only needed for admin and register activation hook.
	 */
	if ( is_admin() ) {
		
		/**
		 * Determine whether or not specific Extender Pro folders
		 * are writable as well as provide their folder names.
		 *
		 * @since 1.0.0
		 * 
		 * @return Extender Pro folder's writable state and names.
		 */
		function extender_pro_folders_writable_check( $folders = false ) {
			
			// Extender Pro folders that need to be writable.
			$extender_pro_folders = array( get_stylesheet_directory(), get_stylesheet_directory() . '/my-templates', extender_pro_get_stylesheet_location( 'path', $root = true ), extender_pro_get_stylesheet_location( 'path' ), extender_pro_get_stylesheet_location( 'path' ) . 'images', extender_pro_get_stylesheet_location( 'path' ) . 'tmp' );
				
			// Set default Extender Pro folder writable state to "false".
			$extender_pro_writable = false;
			
			foreach( $extender_pro_folders as $extender_pro_folder ) {
				
				if ( is_dir( $extender_pro_folder ) && is_writable( $extender_pro_folder ) )
					$extender_pro_writable = true;
				
			}
			
			if ( false !== $folders )
				return $extender_pro_folders;
			else
				return $extender_pro_writable;
			
		}
		
		// Run Extender Pro activation function.
		register_activation_hook( EXTPRO_DIR . 'lib/admin/update/update.php', 'extender_pro_activate' );
	
	}
	
	add_action( 'after_setup_theme', 'extender_pro_dynamik_check', 14 );
	/**
	 * Check if Dynamik Website Builder is active and respod accordingly.
	 *
	 * @since 1.0.0
	 */
	function extender_pro_dynamik_check() {
		
		if ( defined( 'DYN_FONT_AWESOME_VERSION' ) )
			add_action( 'admin_notices', 'extender_pro_dynamik_incompatible_admin_notice' );
		else
			add_action( 'after_setup_theme', 'extender_pro_init', 15 );
		
	}
	
	/**
	 * Localize and initialize the Extender Pro Plugin.
	 *
	 * @since 1.0.0
	 */
	function extender_pro_init() {
		
		// Localization.
		load_plugin_textdomain( 'extender-pro', false, dirname( plugin_basename( __FILE__ ) ) . '/lib/languages' );
	
		// Include Extender Pro files.
		require_once( EXTPRO_DIR . 'lib/init.php' );
		
	}
	
	/**
	 * Display an admin notice stating that Dynamik Website Builder is incompatible with Extender Pro.
	 *
	 * @since 1.0.0
	 */
	function extender_pro_dynamik_incompatible_admin_notice() {
		
	    ?>
	    <div class="notice notice-error" style="clear:both;">
	        <p><?php _e( 'Dynamik Website Builder is not compatible with the Extender Pro Plugin. To use Extender Pro you must activate a different Genesis Child Theme.', 'extender-pro' ); ?></p>
	    </div>
	    <?php
	    
	}
	
}

function extender_pro_requires_compatible_theme_notice() {

	?>
	<div class="error notice">
		<p><?php echo sprintf( __( 'The Extender Pro Plugin requires one of the following <a href="%s" target="_blank">Compatible Themes</a> to function! Either <a href="%s">activate a compatible theme</a> or <a href="%s">deactivate the Extender Pro Plugin</a>.', 'extender-pro' ), 'https://cobaltapps.com/extender-pro-supported-themes/', admin_url( 'themes.php' ), admin_url( 'plugins.php' ) ); ?></p>
	</div>
	<?php
	
}
