<?php
/**
 * Create and hook in the Extender Pro admin menus.
 *
 * @package Extender Pro
 */
 
add_filter( 'admin_body_class', 'extender_pro_admin_body_classes' );
/**
 * Adds custom classes to the array of admin body classes.
 *
 * @since 1.0.0
 *
 * @return array (Maybe) filtered admin body classes.
 */
function extender_pro_admin_body_classes( $classes ) {

	// So Custom CSS knows to disable itself in admin when FE DEV Tools is active.
	if ( extender_pro_get_settings( 'enable_frontend_dev_tools' ) )
		$classes .= ' extender-pro-fe-dev-tools-active ';

	return $classes;
	
}

add_action( 'admin_menu', 'extender_pro_admin_menu' );
/**
 * Create the Extender Pro admin sub menus.
 *
 * @since 1.0.0
 */
function extender_pro_admin_menu() {
	
	$user = wp_get_current_user();
	
	if ( !get_the_author_meta( 'extender_pro_hide_admin_menu', $user->ID ) ) {
		
		add_menu_page( __( 'Extender Pro', 'extender-pro' ), __( 'Extender Pro', 'extender-pro' ), 'manage_options', 'extender-pro-dashboard', 'extender_pro_settings', 'dashicons-laptop', 59 );
		
		$_extender_pro_settings = add_submenu_page( 'extender-pro-dashboard', __( 'Settings', 'extender-pro' ), __( 'Settings', 'extender-pro' ), 'manage_options', 'extender-pro-dashboard', 'extender_pro_settings'  );
		
		add_action( 'admin_print_styles-' . $_extender_pro_settings, 'extender_pro_admin_styles' );
		add_action( 'admin_print_styles-' . $_extender_pro_settings, 'extender_pro_settings_styles' );
		
		$_extender_pro_custom_options = add_submenu_page( 'extender-pro-dashboard', __( 'Custom Options', 'extender-pro' ), __( 'Custom Options', 'extender-pro' ), 'manage_options', 'extender-pro-custom', 'extender_pro_custom_options'  );
		add_action( 'admin_print_styles-' . $_extender_pro_custom_options, 'extender_pro_admin_styles' );
		add_action( 'admin_print_styles-' . $_extender_pro_custom_options, 'extender_pro_custom_styles' );
		
		add_action( 'admin_print_scripts-' . $_extender_pro_custom_options, 'extender_pro_custom_php_vars' );
		
		$_extender_pro_image_manager_options = add_submenu_page( 'extender-pro-dashboard', __( 'Image Manager', 'extender-pro' ), __( 'Image Manager', 'extender-pro' ), 'manage_options', 'extender-pro-image-manager', 'extender_pro_image_manager_options' );
		
		add_action( 'admin_print_styles-' . $_extender_pro_image_manager_options, 'extender_pro_admin_styles' );
		add_action( 'admin_print_styles-' . $_extender_pro_image_manager_options, 'extender_pro_image_manager_admin_styles' );
		
		$_extender_pro_import_export_options = add_submenu_page( 'extender-pro-dashboard', __( 'Import/Export', 'extender-pro' ), __( 'Import/Export', 'extender-pro' ), 'manage_options', 'extender-pro-import-export', 'extender_pro_import_export_options' );
		
		add_action( 'admin_print_styles-' . $_extender_pro_import_export_options, 'extender_pro_admin_styles' );
		
	}
	
}

/**
 * Build the javascript variables that are used in Custom Options.
 *
 * @since 1.0.0
 */
function extender_pro_custom_php_vars() {
	
?>
<script type="text/javascript">
	var extender_pro_list_conditional_examples = '<?php extender_pro_list_conditional_examples(); ?>';
	var extender_pro_list_hooks = '<?php extender_pro_list_hooks(); ?>';
	var extender_pro_list_conditionals = '<?php extender_pro_list_conditionals(); ?>';
</script>
<?php

}

add_action( 'admin_init', 'extender_pro_admin_init' );
/**
 * Register styles and scripts for the Extender Pro admin menus.
 *
 * @since 1.0.0
 */
function extender_pro_admin_init() {
	
	wp_register_style( 'extender_pro_admin_styles', EXTPRO_URL . 'lib/css/admin.css', array(), EXTPRO_VERSION );
	wp_register_style( 'extender_pro_jqui_css', EXTPRO_URL . 'lib/css/smoothness/jquery-ui-1.7.3.custom.css', array(), EXTPRO_VERSION );
	wp_register_style( 'extender_pro_ms_css', EXTPRO_URL . 'lib/js/multiselect/multiselect.css', array(), EXTPRO_VERSION );
	
	wp_register_script( 'extender_pro_ace', EXTPRO_URL . 'lib/js/ace/ace.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_ace_autocomplete', EXTPRO_URL . 'lib/js/ace/ext-language_tools.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_admin', EXTPRO_URL . 'lib/js/admin-options.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_settings', EXTPRO_URL . 'lib/js/settings.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_image_manager', EXTPRO_URL . 'lib/js/image-manager.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_ms_js', EXTPRO_URL . 'lib/js/multiselect/multiselect.js', array(), EXTPRO_VERSION );
	wp_register_script( 'extender_pro_custom', EXTPRO_URL . 'lib/js/custom-options.js', array(), EXTPRO_VERSION );
	
}

/**
 * Enqueue styles and scripts for the Extender Pro admin menus.
 *
 * @since 1.0.0
 */
function extender_pro_admin_styles() {
	
	wp_enqueue_style( 'extender_pro_admin_styles' );
	
	wp_enqueue_script( 'extender_pro_admin' );
	
	$vars = array(
		'aceEditorThemeImageUrl' => EXTPRO_URL . 'lib/css/images/ace-themes/',
	);
	
	wp_localize_script( 'extender_pro_admin', 'extenderAdminL10n', $vars );
	
}

/**
 * Enqueue styles and scripts for the Extender Pro Settings menu.
 *
 * @since 1.0.0
 */
function extender_pro_settings_styles() {
	
	wp_enqueue_script( 'extender_pro_settings' );
	
}

/**
 * Enqueue styles and scripts for the Extender Pro Custom Options menu.
 *
 * @since 1.0.0
 */
function extender_pro_custom_styles() {
	
	wp_enqueue_style( 'extender_pro_jqui_css' );
	wp_enqueue_style( 'extender_pro_ms_css' );
	
	wp_enqueue_script( 'extender_pro_ace' );
	wp_enqueue_script( 'extender_pro_ace_autocomplete' );
	wp_enqueue_script( 'extender_pro_ms_js' );
	wp_enqueue_script( 'extender_pro_custom' );
	
	$enable_ace_editor_syntax_validation = extender_pro_get_settings( 'enable_ace_editor_syntax_validation' );
	$ace_editor_syntax_validation = ! empty( $enable_ace_editor_syntax_validation ) ? 'true' : 'false';
	
	$vars = array(
		'extenderProSiteUrl' => site_url(),
		'extenderProCustomUrl' => admin_url( 'admin.php?page=extender-pro-custom' ),
		'aceEditorSyntaxValidation' => $ace_editor_syntax_validation,
		'eName' => __( 'Name', 'extender-pro' ),
		'eFileName' => __( 'File Name', 'extender-pro' ),
		'eTemplateName' => __( 'Template Name', 'extender-pro' ),
		'eTemplatePostTypes' => __( 'Template Post Types', 'extender-pro' ),
		'eTemplatePostTypeExamples' => __( '(example: page, post, product)', 'extender-pro' ),
		'eLabelCreateConditional' => __( 'Automatically create a Custom Conditional for this Label', 'extender-pro' ),
		'eTag' => __( 'Tag', 'extender-pro' ),
		'eDoShortcode' => __( '[do_shortcode]', 'extender-pro' ),
		'eDelete' => __( 'Delete', 'extender-pro' ),
		'eHook' => __( 'Hook', 'extender-pro' ),
		'ePriority' => __( 'Priority', 'extender-pro' ),
		'eHooked' => __( 'Hooked', 'extender-pro' ),
		'eShortcode' => __( 'Shortcode', 'extender-pro' ),
		'eBoth' => __( 'Both', 'extender-pro' ),
		'eCss' => __( 'CSS', 'extender-pro' ),
		'eJs' => __( 'JS', 'extender-pro' ),
		'eDeactivate' => __( 'Deactivate', 'extender-pro' ),
		'ePageTemplate' => __( 'Page Template', 'extender-pro' ),
		'eWpTemplate' => __( 'WP/Theme Template', 'extender-pro' ),
		'eConditionals' => __( 'Conditionals', 'extender-pro' ),
		'eClass' => __( 'Class', 'extender-pro' ),
		'eDescription' => __( 'Widget Area Description:', 'extender-pro' ),
	);
	
	wp_localize_script( 'extender_pro_custom', 'extenderCustomL10n', $vars );
	
}

/**
 * Enqueue styles and scripts for the Image Manager admin menu.
 *
 * @since 1.0.0
 */
function extender_pro_image_manager_admin_styles() {
	
	wp_enqueue_script( 'extender_pro_image_manager' );
	
}
