<?php
/**
 * Include and setup custom metaboxes and fields.
 *
 * @package  Extender
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

if ( file_exists( dirname( __FILE__ ) . '/cmb2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/cmb2/init.php';
} elseif ( file_exists( dirname( __FILE__ ) . '/CMB2/init.php' ) ) {
	require_once dirname( __FILE__ ) . '/CMB2/init.php';
}

add_action( 'cmb2_admin_init', 'extender_pro_register_labels_metabox' );
/**
 * Hook in and add a labels metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function extender_pro_register_labels_metabox() {
	
	$prefix = '_extender_pro_' . extender_pro_sanitize_string( extender_pro_active_theme_name(), true ) . '_';
	
	foreach( get_post_types( array( 'public' => true ) ) as $post_type )
		$post_types[] = $post_type;
			
	$labels = ! get_option( extender_pro_theme_option_name( 'custom_labels' ) ) ? array() : get_option( extender_pro_theme_option_name( 'custom_labels' ) );
	asort( $labels );
	$labels_array = array();
	foreach( $labels as $key => $value ) {
		$labels_array[$key] = $value['label_id'];
		$labels_array[$key] = $value['label_name'];
	}
	$labels_desc = $labels != array() ? 'Select labels appropriate to this page/post.' : 'No labels available. Go to ( Extender Pro > Extender Custom > Labels ) to create some.';

	/**
	 * Lables metabox
	 */
	$extender_lables = new_cmb2_box( array(
		'id'            => $prefix . 'metabox_labels',
		'title'         => __( 'Extender Pro Labels', 'extender-pro' ),
		'object_types'  => $post_types, // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
	) );

	$extender_lables->add_field( array(
		'name'    => __( 'Select Labels', 'extender-pro' ),
		'desc'    => $labels_desc,
		'id'      => $prefix . 'labels',
		'type'    => 'multicheck',
		'options' => $labels_array,
	) );
	
}

add_action( 'cmb2_admin_init', 'extender_pro_register_user_profile_metabox' );
/**
 * Hook in and add a metabox to add fields to the user profile pages
 */
function extender_pro_register_user_profile_metabox() {
	
	$prefix = 'extender_pro_';

	/**
	 * Metabox for the user profile screen
	 */
	$extender_user = new_cmb2_box( array(
		'id'               => $prefix . 'edit',
		'title'            => __( 'User Profile Metabox', 'extender-pro' ), // Doesn't output for user boxes
		'object_types'     => array( 'user' ), // Tells CMB2 to use user_meta vs post_meta
		'show_names'       => true,
		'new_user_section' => 'add-new-user', // where form will show on new user page. 'add-existing-user' is only other valid option.
	) );

	$extender_user->add_field( array(
		'name'     => __( 'Extender Pro Settings', 'extender-pro' ),
		'id'       => $prefix . 'extra_info',
		'type'     => 'title',
		'on_front' => false,
	) );

	$extender_user->add_field( array(
		'name' => __( 'Extender Pro Admin Menu', 'extender-pro' ),
		'desc' => __( 'Hide Extender Pro Admin Menu?', 'extender-pro' ),
		'id'   => $prefix . 'hide_admin_menu',
		'type' => 'checkbox',
	) );
	
	$extender_user->add_field( array(
		'name' => __( 'Extender Pro License', 'extender-pro' ),
		'desc' => __( 'Hide Extender Pro License Key?', 'extender-pro' ),
		'id'   => $prefix . 'hide_license_key',
		'type' => 'checkbox',
	) );

}
