<?php
/**
 * Builds the Settings admin page.
 *
 * @package Extender Pro
 */
 
/**
 * Build the Extender Pro Settings admin page.
 *
 * @since 1.0.0
 */
function extender_pro_settings() {

?>
	<div class="wrap">
		
		<div id="icon-options-general" class="icon32"></div>
		
		<h2 id="extender-pro-admin-heading"><?php _e( 'Extender Pro - Settings', 'extender-pro' ); ?></h2>
		
		<div id="extender-pro-admin-wrap">
			
			<div class="extender-pro-settings-wrap">
				<?php require_once( EXTPRO_DIR . 'lib/admin/boxes/settings.php' ); ?>
			</div>
			
		</div>
	</div> <!-- Close Wrap -->
<?php

}

add_action( 'wp_ajax_extender_pro_settings_save', 'extender_pro_settings_save' );
/**
 * Use ajax to update the Extender Pro Settings based on the posted values.
 *
 * @since 1.0.0
 */
function extender_pro_settings_save() {
	
	check_ajax_referer( 'extender-pro-ajax-nonce', 'security' );
	
	$update = $_POST['extender'];
	update_option( 'extender_pro_settings', $update );
	
	extender_pro_write_files( $css = true, $custom = false );
	
	echo 'Settings Updated';
	exit();
	
}

add_action( 'wp_ajax_extender_pro_custom_options_reset', 'extender_pro_custom_options_reset' );
/**
 * Use ajax to reset the Extender Pro Custom Options.
 *
 * @since 1.0.0
 */
function extender_pro_custom_options_reset() {
	
	check_ajax_referer( 'extender-pro-ajax-nonce', 'security' );
	
	extender_pro_reset_delete_template();
	update_option( extender_pro_theme_option_name( 'custom_styles' ), '' );
	update_option( extender_pro_theme_option_name( 'custom_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your functions below. (NOTE: These functions affect both front-end AND admin.) */' . "\n" );
	update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your front-end functions below. (These functions affect front-end only.) */' . "\n" );
	update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), '' );
	update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), '' );
	update_option( extender_pro_theme_option_name( 'custom_templates' ), array() );
	update_option( extender_pro_theme_option_name( 'custom_labels' ), array() );
	update_option( extender_pro_theme_option_name( 'custom_conditionals' ), array() );
	update_option( extender_pro_theme_option_name( 'custom_widget_areas' ), array() );
	update_option( extender_pro_theme_option_name( 'custom_hook_boxes' ), array() );
	
	extender_pro_write_files( $css = true );
	
	echo 'Reset Successful';
	exit();
	
}

/**
 * Create an array of Plugin Settings default values.
 *
 * @since 1.0.0
 * @return an array of Plugin Settings default values.
 */
function extender_pro_settings_defaults() {
	
	$defaults = array(
		'enable_frontend_dev_tools' => 0,
		'enable_frontend_hooks_map' => 0,
		'enable_minified_scripts' => 1,
		'enable_ace_editor_syntax_validation' => 1,
		'enable_protocol_relative_urls' => 0,
	);
	
	return apply_filters( 'extender_pro_settings_defaults', $defaults );
	
}
