<?php
/**
 * Handles both the activation and update functionality.
 *
 * @package Extender Pro
 */

add_action( 'admin_init', 'extender_pro_update' );
/**
 * Perform Extender Pro updates based on current version number.
 *
 * @since 1.0.0
 */
function extender_pro_update() {
	
	// Initialize the update sequence.
	extender_pro_activate_pre();
	
	// Don't do anything if we're on the latest version.
	if ( version_compare( get_option( 'extender_pro_version_number' ), EXTPRO_VERSION, '>=' ) )
		return;

	// Update to Extender Pro 1.0.1
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.1', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.1' );
		
	// Update to Extender Pro 1.0.2
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.2', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.2' );
		
	// Update to Extender Pro 1.0.3
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.3', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.3' );
		
	// Update to Extender Pro 1.0.4
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.4', '<' ) ) {	
		
		$extender_pro_settings = get_option( 'extender_pro_settings' );
		$new_extender_pro_settings = array(
			'enable_protocol_relative_urls' => 0,
		);
		$extender_pro_settings = wp_parse_args( $new_extender_pro_settings, $extender_pro_settings );
		update_option( 'extender_pro_settings', $extender_pro_settings );
		
		update_option( 'extender_pro_version_number', '1.0.4' );
		
	}
	
	// Update to Extender Pro 1.0.5
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.5', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.5' );
		
	// Update to Extender Pro 1.0.6
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.6', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.6' );
		
	// Update to Extender Pro 1.0.7
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.7', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.7' );
		
	// Update to Extender Pro 1.0.8
	if ( version_compare( get_option( 'extender_pro_version_number' ), '1.0.8', '<' ) )
		update_option( 'extender_pro_version_number', '1.0.8' );
	
	// Finalize the update sequence.
	extender_pro_activate_post();
	
}

/**
 * Perform Extender Pro (pre) activation actions.
 *
 * @since 1.0.0
 */
function extender_pro_activate_pre() {
	
	if ( ! get_option( 'extender_pro_settings' ) )
		update_option( 'extender_pro_settings', extender_pro_settings_defaults() );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_styles' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_styles' ), '' );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_functions' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your functions below. (NOTE: These functions affect both front-end AND admin.) */' . "\n" );
		
	if ( ! get_option( extender_pro_theme_option_name( 'custom_frontend_functions' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your front-end functions below. (These functions affect front-end only.) */' . "\n" );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_header_scripts' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), '' );
		
	if ( ! get_option( extender_pro_theme_option_name( 'custom_footer_scripts' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), '' );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_templates' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_templates' ), array() );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_labels' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_labels' ), array() );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_conditionals' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_conditionals' ), array() );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_widget_areas' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_widget_areas' ), array() );

	if ( ! get_option( extender_pro_theme_option_name( 'custom_hook_boxes' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_hook_boxes' ), array() );
		
}

/**
 * Perform Extender Pro (post) activation actions.
 *
 * @since 1.0.0
 */
function extender_pro_activate_post() {

	if ( ! get_option( 'extender_pro_version_number' ) )
		update_option( 'extender_pro_version_number', EXTPRO_VERSION );

	extender_pro_dir_check( get_stylesheet_directory() . '/my-templates' );
	extender_pro_dir_check( extender_pro_get_stylesheet_location( 'path', $root = true ) );
	extender_pro_dir_check( extender_pro_get_stylesheet_location( 'path', $root = true ) . extender_pro_active_theme_name() );
	extender_pro_dir_check( extender_pro_get_stylesheet_location( 'path' ) . 'images' );
	extender_pro_dir_check( extender_pro_get_stylesheet_location( 'path' ) . 'tmp' );

	extender_pro_write_files();
	extender_pro_create_custom_functions_file();
	extender_pro_create_custom_frontend_functions_file();
	
	if ( false === extender_pro_folders_writable_check() )
		wp_redirect( admin_url( 'admin.php?page=extender-pro-dashboard&notice=extender-pro-unwritable' ) );

}

/**
 * Perform Extender Pro activation actions.
 *
 * @since 1.0.0
 */
function extender_pro_activate() {
	
	extender_pro_activate_pre();
	extender_pro_activate_post();
	
}

add_action( 'admin_init', 'extender_pro_new_theme_file_check' );
/**
 * Run extender_pro_activate_post() function on Appearance > Themes.
 * admin page. This helps ensure that the necessary activation operations
 * are perfomrmed if a new framework theme has just been activated.
 *
 * @since 1.0.0
 */
function extender_pro_new_theme_file_check() {
	
	global $pagenow;
	if ( $pagenow != 'themes.php' )
		return;
		
	extender_pro_activate_post();
	
}
