<?php
/**
 * Handles the frontend css sandbox functionality.
 *
 * @package Extender Pro
 */
 
add_action( 'wp_head', 'extender_pro_css_echo', 15 );
/**
 * Echo the active theme's styles into the <head>.
 *
 * @since 1.0.0
 */
function extender_pro_css_echo() {

	$styles = stripslashes( get_option( extender_pro_theme_option_name( 'custom_styles' ) ) );
	$styles = str_replace( 'url(images', 'url(' . extender_pro_get_stylesheet_location( 'url' ) . 'images', $styles );
	$styles = str_replace( 'url(\'images', 'url(\'' . extender_pro_get_stylesheet_location( 'url' ) . 'images', $styles );
	$styles = str_replace( 'url("images', 'url("' . extender_pro_get_stylesheet_location( 'url' ) . 'images', $styles );
	$output = "\n\n<!-- Begin echoed custom styles -->\n<style id=\"extender-pro-custom-styles-echo\" type=\"text/css\">\n" . $styles . "</style>\n<!-- End echoed custom styles -->\n";
	
	echo $output;
	
}

add_action( 'wp_enqueue_scripts', 'extender_pro_fe_dev_tools_enqueue_scripts' );
/**
 * Enqueue frontend css sandbox styles and scripts.
 *
 * @since 1.0.0
 */
function extender_pro_fe_dev_tools_enqueue_scripts() {

	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'extender_pro_fe_dev_tools_styles', EXTPRO_URL . 'lib/css/fe-dev-tools.css' );
	wp_enqueue_style( 'extender_pro_jquery_ui_css', '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.4/themes/smoothness/jquery-ui.css', false, EXTPRO_VERSION, false );
	wp_enqueue_script( 'jquery-ui-resizable' );
	wp_enqueue_script( 'extender_pro_fe_dev_tools_scripts', EXTPRO_URL . 'lib/js/fe-dev-tools.js', array( 'jquery', 'jquery-ui-draggable' ), EXTPRO_VERSION, true );
	wp_enqueue_script( 'extender_pro_ace', EXTPRO_URL . 'lib/js/ace/ace.js', array(), EXTPRO_VERSION, true );
	wp_enqueue_script( 'extender_pro_ace_autocomplete', EXTPRO_URL . 'lib/js/ace/ext-language_tools.js', array(), EXTPRO_VERSION, true );
	
	$enable_ace_editor_syntax_validation = extender_pro_get_settings( 'enable_ace_editor_syntax_validation' );
	$ace_editor_syntax_validation = ! empty( $enable_ace_editor_syntax_validation ) ? true : false;
	
	$vars = array(
		'aceEditorSyntaxValidation' => $ace_editor_syntax_validation,
		'ajaxurl' => admin_url( 'admin-ajax.php' ),
		'styleEditorNonce' => wp_create_nonce( 'extender-pro-ajax-nonce' ),
		'saveButtonText' => __( 'Save Changes', 'extender-pro' ),
		'saveSpinner' => EXTPRO_URL . 'lib/css/images/ajax-save-in-progress.gif',
		'customStyles' => esc_textarea( stripslashes( get_option( extender_pro_theme_option_name( 'custom_styles' ) ) ) ),
		'extProImagesUrl' => 'url(' . extender_pro_get_stylesheet_location( 'url' ) . 'images',
		'extProImagesUrlSingleQuotes' => 'url(\'' . extender_pro_get_stylesheet_location( 'url' ) . 'images',
		'extProImagesUrlDoubleQuotes' => 'url("' . extender_pro_get_stylesheet_location( 'url' ) . 'images',
		'cssSandboxHeading' => __( 'CSS Sandbox', 'extender-pro' ),
		'cssSandboxCopied' => __( 'CSS Copied!', 'extender-pro' ),
		'htmlSandboxHeading' => __( 'HTML Sandbox', 'extender-pro' ),
		'htmlSandboxCopied' => __( 'HTML Copied!', 'extender-pro' ),
		'htmlTitleCopyCss' => __( 'Copy CSS', 'extender-pro' ),
		'htmlTitleCopyHtml' => __( 'Copy HTML', 'extender-pro' ),
		'htmlTitleOpenStyle' => __( 'Open Style Editor', 'extender-pro' ),
		'htmlTitleOpenCss' => __( 'Open CSS Sandbox', 'extender-pro' ),
		'htmlTitleOpenHtml' => __( 'Open HTML Sandbox', 'extender-pro' ),
		'htmlTitleUndoResize' => __( 'Undo Textarea Resize', 'extender-pro' ),
		'htmlTitleClearTextarea' => __( 'Clear The Textarea', 'extender-pro' ),
		'htmlTitleWrapOn' => __( 'Turn Text Wrap On', 'extender-pro' ),
		'htmlTitleWrapOff' => __( 'Turn Text Wrap Off', 'extender-pro' ),
	);
	
	wp_localize_script( 'extender_pro_fe_dev_tools_scripts', 'extenderDevToolsL10n', $vars );
		
}
