<?php
/**
 * Handles the frontend hooks map functionality.
 *
 * @package Extender Pro
 */

add_action( 'wp_head', 'extender_pro_hooks_map' );
/**
 * Build the frontend hooks map tab and as well as the active framework action
 * hooks, displayed when tab is clicked (visible to logged in admins only).
 *
 * @since 1.0.0
 */
function extender_pro_hooks_map() {
    
    // Build the frontend hooks map tab.
    echo '<span id="extender-pro-hooks-map" style="display:none;"><span class="dashicons dashicons-location-alt"></span></span>' . "\n";
    
    // Get the active framework action hooks array.
    $hooks_array = extender_pro_hooks_array();
    $hooks = $hooks_array['hooks'][$hooks_array['framework']];
    
    /*
     * Loop through the active framework action hooks array and build
     * the necessary divs to properly display them.
     */
    foreach ( $hooks as $hook )
        add_action( '' . $hook . '', function() use ( $hook ) { echo '<div id="' . $hook . '" class="extender-pro-mapped-hooks"></div>'; } );
    
}

/**
 * Build an array of active framework action hooks.
 *
 * @since 1.0.0
 * @return an array of active framework action hooks.
 */
function extender_pro_hooks_array() {
	
	$active_parent_theme = wp_get_theme( get_template() );
	$active_parent_theme = strtolower( str_replace( array( '-', ' ' ), '_', $active_parent_theme->Name ) );
	
    $theme_hooks = array(
        'framework' => $active_parent_theme,
        'hooks' => array(
            'astra' => array(
                'astra_html_before',
                'astra_head_top',
                'astra_head_bottom',
                'wp_head',
                'astra_body_top',
                'astra_header_before',
                'astra_masthead_top',
                'astra_main_header_bar_top',
                'astra_masthead_content',
                'astra_masthead_toggle_buttons_before',
                'astra_masthead_toggle_buttons_after',
                'astra_main_header_bar_bottom',
                'astra_masthead_bottom',
                'astra_header_after',
                'astra_content_before',
                'astra_content_top',
                'astra_primary_content_top',
                'astra_content_while_before',
                'astra_entry_before',
                'astra_entry_top',
                'astra_single_header_before',
                'astra_single_header_top',
                'astra_single_header_bottom',
                'astra_single_header_after',
                'astra_entry_content_before',
                'astra_entry_content_after',
                'astra_entry_bottom',
                'astra_entry_after',
                'astra_primary_content_bottom',
                'astra_content_while_after',
                'astra_content_bottom',
                'astra_content_after',
                'astra_comments_before',
                'astra_comments_after',
                'astra_sidebars_before',
                'astra_sidebars_after',
                'astra_footer_before',
                'astra_footer_content_top',
                'astra_footer_content_bottom',
                'astra_footer_after',
                'astra_body_bottom',
                'wp_footer',
            ),
            'freelancer' => array(
    			'freelancer_before',
    			'freelancer_after',
    			'freelancer_before_header',
    			'freelancer_header',
    			'freelancer_after_header',
    			'freelancer_in_header',
    			'freelancer_in_header_main',
    			'freelancer_site_branding_logo',
    			'freelancer_site_branding_text',
    			'freelancer_site_title',
    			'freelancer_site_description',
    			'freelancer_in_header_menu',
    			'freelancer_before_site_content',
    			'freelancer_after_site_content',
    			'freelancer_before_content_area',
    			'freelancer_after_content_area',
    			'freelancer_before_content',
    			'freelancer_after_content',
    			'freelancer_before_entry',
    			'freelancer_after_entry',
    			'freelancer_entry_header',
    			'freelancer_inside_entry_header',
    			'freelancer_post_meta_top',
    			'freelancer_before_entry_content',
    			'freelancer_entry_content',
    			'freelancer_after_entry_content',
    			'freelancer_entry_footer',
    			'freelancer_inside_entry_footer',
    			'freelancer_post_meta_bottom',
    			'freelancer_404_entry_content',
    			'freelancer_no_entry_content',
    		    'freelancer_before_while',
    			'freelancer_before_loop',
    			'freelancer_loop',
    			'freelancer_after_loop',
    			'freelancer_after_endwhile',
    			'freelancer_loop_else',
    			'freelancer_before_comments',
    			'freelancer_comments',
    			'freelancer_after_comments',
    			'freelancer_before_comment_form',
    			'freelancer_comment_form',
    			'freelancer_after_comment_form',
    			'freelancer_before_sidebar',
    			'freelancer_sidebar',
    			'freelancer_after_sidebar',
    			'freelancer_before_footer',
    			'freelancer_footer',
    			'freelancer_after_footer',
    			'freelancer_in_footer',
    			'freelancer_credits',
            ),
            'genesis' => array(
        		'genesis_before',
        		'genesis_after',
        		'genesis_before_header',
        		'genesis_header',
        		'genesis_after_header',
        		'genesis_site_title',
        		'genesis_site_description',
        		'genesis_header_right',
        		'genesis_before_content_sidebar_wrap',
        		'genesis_after_content_sidebar_wrap',
        		'genesis_before_content',
        		'genesis_after_content',
        		'genesis_extender_before_ez_home',
        		'genesis_extender_after_ez_home',
        		'genesis_before_entry',
        		'genesis_after_entry',
        		'genesis_entry_header',
        		'genesis_before_entry_content',
        		'genesis_entry_content',
        		'genesis_after_entry_content',
        		'genesis_entry_footer',
        		'genesis_before_post',
        		'genesis_after_post',
        		'genesis_before_post_title',
        		'genesis_post_title',
        		'genesis_after_post_title',
        		'genesis_before_post_content',
        		'genesis_post_content',
        		'genesis_after_post_content',
        		'genesis_before_loop',
        		'genesis_loop',
        		'genesis_after_loop',
        		'genesis_after_endwhile',
        		'genesis_loop_else',
        		'genesis_before_comments',
        		'genesis_comments',
        		'genesis_after_comments',
        		'genesis_list_comments',
        		'genesis_before_pings',
        		'genesis_pings',
        		'genesis_after_pings',
        		'genesis_before_comment',
        		'genesis_after_comment',
        		'genesis_before_comment_form',
        		'genesis_comment_form',
        		'genesis_after_comment_form',
        		'genesis_sidebar',
        		'genesis_before_sidebar_widget_area',
        		'genesis_after_sidebar_widget_area',
        		'genesis_sidebar_alt',
        		'genesis_before_sidebar_alt_widget_area',
        		'genesis_after_sidebar_alt_widget_area',
        		'genesis_before_footer',
        		'genesis_footer',
        		'genesis_after_footer',            
            ),
            'beaver_builder_theme' => array(
                'fl_head_open' => 'fl_head_open',
                'fl_head' => 'fl_head',
                'fl_body_open' => 'fl_body_open',
                'fl_page_open' => 'fl_page_open',
                'fl_before_top_bar' => 'fl_before_top_bar',
                'fl_top_bar_col1_open' => 'fl_top_bar_col1_open',
                'fl_top_bar_col1_close' => 'fl_top_bar_col1_close',
                'fl_top_bar_col2_open' => 'fl_top_bar_col2_open',
                'fl_top_bar_col2_close' => 'fl_top_bar_col2_close',
                'fl_after_top_bar' => 'fl_after_top_bar',
                'fl_before_header' => 'fl_before_header',
                'fl_header_content_open' => 'fl_header_content_open',
                'fl_header_content_close' => 'fl_header_content_close',
                'fl_after_header' => 'fl_after_header',
                'fl_before_content' => 'fl_before_content',
                'fl_content_open' => 'fl_content_open',
                'fl_post_top_meta_open' => 'fl_post_top_meta_open',
                'fl_post_top_meta_close' => 'fl_post_top_meta_close',
                'fl_post_bottom_meta_open' => 'fl_post_bottom_meta_open',
                'fl_post_bottom_meta_close' => 'fl_post_bottom_meta_close',
                'fl_comments_open' => 'fl_comments_open',
                'fl_comments_close' => 'fl_comments_close',
                'fl_sidebar_open' => 'fl_sidebar_open',
                'fl_sidebar_close' => 'fl_sidebar_close',
                'fl_content_close' => 'fl_content_close',
                'fl_after_content' => 'fl_after_content',
                'fl_footer_wrap_open' => 'fl_footer_wrap_open',
                'fl_before_footer_widgets' => 'fl_footer_wrap_open',
                'fl_after_footer_widgets' => 'fl_after_footer_widgets',
                'fl_before_footer' => 'fl_before_footer',
                'fl_after_footer' => 'fl_after_footer',
                'fl_footer_col1_open' => 'fl_footer_col1_open',
                'fl_footer_col1_close' => 'fl_footer_col1_close',
                'fl_footer_col2_open' => 'fl_footer_col2_open',
                'fl_footer_col2_close' => 'fl_footer_col2_close',
                'fl_footer_wrap_close' => 'fl_footer_wrap_close',
                'fl_page_close' => 'fl_page_close',
                'fl_body_close' => 'fl_body_close',           
            ),
            'generatepress' => array(
        		'generate_before_header',
        		'generate_after_header',
        		'generate_header',
        		'generate_before_header_content',
        		'generate_after_header_content',
        		'generate_inside_mobile_header',
        		'generate_inside_navigation',
        		'generate_inside_secondary_navigation',
        		'generate_inside_slideout_navigation',
        		'generate_inside_mobile_header_menu',
        		'generate_inside_mobile_menu_bar',
        		'generate_inside_mobile_menu',
        		'generate_inside_secondary_mobile_menu',
        		'generate_inside_container',
        		'generate_before_main_content',
        		'generate_after_main_content',
        		'generate_before_content',
        		'generate_after_content',
        		//'generate_after_primary_content_area', ** Excluded from Hooks Map because it pushes down sidebar. **
        		'generate_after_entry_title',
        		'generate_after_entry_header',
        		'generate_after_entry_content',
        		'generate_before_archive_title',
        		'generate_after_archive_title',
        		'generate_archive_title',
        		'generate_after_archive_description',
        		'generate_paging_navigation',
        		'generate_before_comments',
        		'generate_inside_comments',
        		'generate_sidebars',
        		'generate_before_left_sidebar_content',
        		'generate_after_left_sidebar_content',
        		'generate_before_right_sidebar_content',
        		'generate_after_right_sidebar_content',
        		'generate_before_footer',
        		'generate_before_footer_content',
        		'generate_after_footer_content',
        		'generate_after_footer_widgets',
        		'generate_before_copyright',
        		'generate_credits',
            ),
            'oceanwp' => array(
    			'ocean_before_outer_wrap',
    			'ocean_after_outer_wrap',
    			'ocean_before_wrap',
    			'ocean_after_wrap',
    			'ocean_before_top_bar',
    			'ocean_after_top_bar',
    			'ocean_before_top_bar_inner',
    			'ocean_after_top_bar_inner',
    			'ocean_before_header',
    			'ocean_after_header',
    			'ocean_before_header_inner',
    			'ocean_after_header_inner',
    			'ocean_before_logo',
    			'ocean_after_logo',
    			'ocean_before_logo_inner',
    			'ocean_after_logo_inner',
    			'ocean_before_nav',
    			'ocean_after_nav',
    			'ocean_before_nav_inner',
    			'ocean_after_nav_inner',
    			'ocean_before_page_header',
    			'ocean_after_page_header',
    			'ocean_before_page_header_inner',
    			'ocean_after_page_header_inner',
    			'ocean_before_main',
    			'ocean_after_main',
    			'ocean_before_content_wrap',
    			'ocean_before_content_wrap',
    			'ocean_before_primary',
    			'ocean_after_primary',
    			'ocean_before_content',
    			'ocean_after_content',
    			'ocean_before_content_inner',
    			'ocean_after_content_inner',
    			'ocean_before_page_entry',
    			'ocean_after_page_entry',
    			'ocean_before_blog_entry_title',
    			'ocean_after_blog_entry_title',
    			'ocean_before_blog_entry_meta',
    			'ocean_after_blog_entry_meta',
    			'ocean_before_blog_entry_content',
    			'ocean_after_blog_entry_content',
    			'ocean_before_blog_entry_readmore',
    			'ocean_after_blog_entry_readmore',
    			'ocean_before_single_post_title',
    			'ocean_after_single_post_title',
    			'ocean_before_single_post_meta',
    			'ocean_after_single_post_meta',
    			'ocean_before_single_post_content',
    			'ocean_after_single_post_content',
    			'ocean_before_single_post_next_prev',
    			'ocean_after_single_post_next_prev',
    			'ocean_before_single_post_related_posts',
    			'ocean_after_single_post_related_posts',
    			'ocean_before_single_product_title',
    			'ocean_after_single_product_title',
    			'ocean_before_single_product_meta',
    			'ocean_after_single_product_meta',
    			'ocean_before_single_product_excerpt',
    			'ocean_after_single_product_excerpt',
    			'ocean_before_single_product_price',
    			'ocean_after_single_product_price',
    			'ocean_before_single_product_rating',
    			'ocean_after_single_product_rating',
    			'ocean_before_single_product_quantity-button',
    			'ocean_after_single_product_quantity-button',
    			'ocean_before_archive_product_title',
    			'ocean_after_archive_product_title',
    			'ocean_before_archive_product_inner',
    			'ocean_after_archive_product_inner',
    			'ocean_before_archive_product_item',
    			'ocean_after_archive_product_item',
    			'ocean_before_archive_product_image',
    			'ocean_after_archive_product_image',
    			'ocean_before_archive_product_add_to_cart',
    			'ocean_after_archive_product_add_to_cart',
    			'ocean_before_archive_product_description',
    			'ocean_after_archive_product_description',
    			'ocean_before_archive_product_categories',
    			'ocean_after_archive_product_categories',
    			'ocean_before_single_post_author_bio',
    			'ocean_after_single_post_author_bio',
    			'ocean_before_sidebar',
    			'ocean_after_sidebar',
    			'ocean_before_sidebar_inner',
    			'ocean_after_sidebar_inner',
    			'ocean_before_footer',
    			'ocean_after_footer',
    			'ocean_before_footer_inner',
    			'ocean_after_footer_inner',
    			'ocean_before_footer_widgets',
    			'ocean_after_footer_widgets',
    			'ocean_before_footer_widgets_inner',
    			'ocean_after_footer_widgets_inner',
    			'ocean_before_footer_bottom',
    			'ocean_after_footer_bottom',
    			'ocean_before_footer_bottom_inner',
    			'ocean_after_footer_bottom_inner',
            ),
        ),
    );
    
    return $theme_hooks;
    
}

add_action( 'wp_enqueue_scripts', 'extender_pro_hooks_map_enqueue_scripts' );
/**
 * Enqueue frontend hooks map styles and scripts.
 *
 * @since 1.0.0
 */
function extender_pro_hooks_map_enqueue_scripts() {

	wp_enqueue_style( 'extender_pro_hooks_map_styles', EXTPRO_URL . 'lib/css/hooks-map.css' );
	wp_enqueue_script( 'extender_pro_hooks_map_scripts', EXTPRO_URL . 'lib/js/hooks-map.js', array( 'jquery' ), EXTPRO_VERSION, true );
		
}
