<?php
/**
 * Handels all the Import/Export functionality in Extender Pro
 * and the Extender Pro Child Theme.
 *
 * @package Extender Pro
 */

/**
 * Create a string that represnts the current date and time.
 *
 * @since 1.0.0
 * @return string that represnts the current date and time.
 */
function extender_pro_time() {
	
	$time = gmdate( 'Y-m-d H:i:s', ( time() + ( get_option( 'gmt_offset' ) * 3600 ) ) );
	return strtotime( $time );
	
}

/**
 * Export the specified Custom Option settings.
 *
 * @since 1.0.0
 */
function extender_pro_custom_export( $export_name = false, $theme_settings = '', $custom_styles = '', $custom_functions = '', $custom_scripts = '', $custom_templates = '', $custom_labels = '', $conditionals = '', $widget_areas = '', $hook_boxes = '', $images = '' ) {
	
	$export_data = array();
	
	if ( ! empty( $theme_settings ) )
		$export_data['extender_pro_settings'] = get_option( 'extender_pro_settings' );
	
	if ( ! empty( $custom_styles ) )
		$export_data['extender_pro_custom_styles'] = get_option( extender_pro_theme_option_name( 'custom_styles' ) );
	
	if ( ! empty( $custom_functions ) ) {
		
		$export_data['extender_pro_custom_functions'] = get_option( extender_pro_theme_option_name( 'custom_functions' ) );
		$export_data['extender_pro_custom_frontend_functions'] = get_option( extender_pro_theme_option_name( 'custom_frontend_functions' ) );
		
	}

	if ( ! empty( $custom_scripts ) ) {
		
		$export_data['extender_pro_custom_header_scripts'] = get_option( extender_pro_theme_option_name( 'custom_header_scripts' ) );
		$export_data['extender_pro_custom_footer_scripts'] = get_option( extender_pro_theme_option_name( 'custom_footer_scripts' ) );
		
	}

	if ( ! empty( $custom_templates ) )
		$export_data['extender_pro_templates'] = get_option( extender_pro_theme_option_name( 'custom_templates' ) );

	if ( ! empty( $custom_labels ) )
		$export_data['extender_pro_labels'] = get_option( extender_pro_theme_option_name( 'custom_labels' ) );
	
	if ( ! empty( $conditionals ) )
		$export_data['extender_pro_conditionals'] = get_option( extender_pro_theme_option_name( 'custom_conditionals' ) );
	
	if ( ! empty( $widget_areas ) )
		$export_data['extender_pro_widgets'] = get_option( extender_pro_theme_option_name( 'custom_widget_areas' ) );
	
	if ( ! empty( $hook_boxes ) )
		$export_data['extender_pro_hooks'] = get_option( extender_pro_theme_option_name( 'custom_hook_boxes' ) );

	$extender_pro_datestamp = date( 'YmdHis', extender_pro_time() );

	if ( $export_name )
		$extender_pro_export_dat = extender_pro_sanitize_string( $export_name, true ) . '.dat';
	else
		$extender_pro_export_dat = 'extender_pro_' . extender_pro_sanitize_string( extender_pro_active_theme_name(), true ) . '_' . $extender_pro_datestamp . '.dat';

	$cheerios = serialize( $export_data );
	
	if ( ! empty( $images ) ) {
		
		extender_pro_cleanup_dir( extender_pro_get_stylesheet_location( 'path' ) . 'tmp' );
		require_once( ABSPATH . 'wp-admin/includes/class-pclzip.php' );
		
		if ( $export_name )
			$extender_pro_export_zip = extender_pro_sanitize_string( $export_name, true ) . '.zip';
		else
			$extender_pro_export_zip = 'extender_pro_' . extender_pro_sanitize_string( extender_pro_active_theme_name(), true ) . '_' . $extender_pro_datestamp . '.zip';
		
		$tmp_path = extender_pro_get_stylesheet_location( 'path' ) . 'tmp';
		$dat_filename = $tmp_path . '/' . $extender_pro_export_dat;
		$dat_file = fopen( $dat_filename, 'x' );
		fwrite( $dat_file, $cheerios );
		fclose ( $dat_file );
		$tmp_image_folder = $tmp_path . '/images';
		
		extender_pro_copy_dir( extender_pro_get_stylesheet_location( 'path' ) . 'images', $tmp_image_folder );
		
		$export_files = array( $dat_filename, $tmp_image_folder );
		
		$extender_pro_pclzip = new PclZip( $tmp_path . '/' . $extender_pro_export_zip );
		$extender_pro_zipped = $extender_pro_pclzip->create( $export_files, PCLZIP_OPT_REMOVE_PATH, $tmp_path );
		if ( $extender_pro_zipped == 0 )
			die( "Error : " . $extender_pro_pclzip->errorInfo( true ) );
	
		if ( ob_get_level() )
			ob_end_clean();
	
		header( "Cache-Control: public, must-revalidate" );
		header( "Pragma: hack" );
		header( "Content-Type: application/zip" );
		header( "Content-Disposition: attachment; filename=$extender_pro_export_zip" );
		readfile( $tmp_path . '/' . $extender_pro_export_zip );
		extender_pro_delete_dir( $tmp_path );
		
		exit();
		
	} else {
		
		header( "Content-type: text/plain" );
		header( "Content-disposition: attachment; filename=$extender_pro_export_dat" );
		header( "Content-Transfer-Encoding: binary" );
		header( "Pragma: no-cache" );
		header( "Expires: 0" );
		echo $cheerios;
		exit();
		
	}
		
}

/**
 * Import the specified Custom Option settings into
 * their appropriate sections of the wp_options table.
 *
 * @since 1.0.0
 */
function extender_pro_custom_import( $import_file, $theme_settings = '', $custom_styles = '', $custom_functions = '', $custom_scripts = '', $custom_templates = '', $custom_labels = '', $conditionals = '', $widget_areas = '', $hook_boxes = '', $images = '' ) {
	
	$extender_pro_templates = get_option( extender_pro_theme_option_name( 'custom_templates' ) );
	$extender_pro_labels = get_option( extender_pro_theme_option_name( 'custom_labels' ) );
	$extender_pro_conditionals = get_option( extender_pro_theme_option_name( 'custom_conditionals' ) );
	$extender_pro_widgets = get_option( extender_pro_theme_option_name( 'custom_widget_areas' ) );
	$extender_pro_hooks = get_option( extender_pro_theme_option_name( 'custom_hook_boxes' ) );
	
	$tmp_path = extender_pro_get_stylesheet_location( 'path' ) . 'tmp';
	extender_pro_cleanup_dir( $tmp_path );
	$tmp_import_folder = $tmp_path . '/import';
	
	if ( 'zip' == strtolower( substr( strrchr( $import_file['name'], '.' ), 1 ) ) ) {
		
		require_once( ABSPATH . 'wp-admin/includes/class-pclzip.php' );

		$import_tmp_name = $import_file['tmp_name'];
		$import_dat_name = str_replace( '.zip', '.dat', $import_file['name'] );
		$zip_file = new PclZip( $import_tmp_name );
		
		if ( ( $unzip_result_list = $zip_file->extract( PCLZIP_OPT_PATH, $tmp_import_folder ) ) == 0 )
			die( "Error : " . $zip_file->errorInfo( true ) );
			
		if ( file_exists( $tmp_import_folder . '/' . $import_dat_name ) ) {
			
			$import_data = file_get_contents( $tmp_import_folder . '/' . $import_dat_name );
			$extender_pro_import = unserialize( $import_data );
			
			if ( ! empty( $theme_settings ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_settings'] ) ) {
					
					$plugin_settings_import = array_merge( extender_pro_settings_defaults( false, $extender_pro_import['extender_pro_settings'] ), $extender_pro_import['extender_pro_settings'] );
					update_option( 'extender_pro_settings', $plugin_settings_import );
					
				}
				
			}
			
			if ( ! empty( $custom_styles ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_custom_styles'] ) )
					update_option( extender_pro_theme_option_name( 'custom_styles' ), $extender_pro_import['extender_pro_custom_styles'] );
				
			}
			
			if ( ! empty( $custom_functions ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_custom_functions'] ) )
					update_option( extender_pro_theme_option_name( 'custom_functions' ), $extender_pro_import['extender_pro_custom_functions'] );
					
				if ( ! empty( $extender_pro_import['extender_pro_custom_frontend_functions'] ) )
					update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), $extender_pro_import['extender_pro_custom_frontend_functions'] );
				
			}
	
			if ( ! empty( $custom_scripts ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_custom_header_scripts'] ) )
					update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), $extender_pro_import['extender_pro_custom_header_scripts'] );
					
				if ( ! empty( $extender_pro_import['extender_pro_custom_footer_scripts'] ) )
					update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), $extender_pro_import['extender_pro_custom_footer_scripts'] );
				
			}
	
			if ( ! empty( $custom_templates ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_templates'] ) ) {
					
					$extender_pro_templates_array = array();
					foreach( $extender_pro_templates as $key => $value ) {
						
						if ( !in_array( $extender_pro_templates[$key]['template_file_name'], $extender_pro_templates_array ) )
							$extender_pro_templates_array[] = $extender_pro_templates[$key]['template_file_name'];
	
					}
					foreach( $extender_pro_import['extender_pro_templates'] as $key => $value ) {
						
						if ( in_array( $extender_pro_import['extender_pro_templates'][$key]['template_file_name'], $extender_pro_templates_array ) )
							unset( $extender_pro_import['extender_pro_templates'][$key] );
	
					}
					$templates_import = array_merge( $extender_pro_templates, $extender_pro_import['extender_pro_templates'] );
					update_option( extender_pro_theme_option_name( 'custom_templates' ), $templates_import );
					
				}
				
			}
	
			if ( ! empty( $custom_labels ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_labels'] ) ) {
					
					$extender_pro_labels_array = array();
					foreach( $extender_pro_labels as $key => $value ) {
						
						if ( !in_array( $extender_pro_labels[$key]['label_name'], $extender_pro_labels_array ) )
							$extender_pro_labels_array[] = $extender_pro_labels[$key]['label_name'];
							
					}
					foreach( $extender_pro_import['extender_pro_labels'] as $key => $value ) {
						
						if ( in_array( $extender_pro_import['extender_pro_labels'][$key]['label_name'], $extender_pro_labels_array ) )
							unset( $extender_pro_import['extender_pro_labels'][$key] );
	
					}
					$labels_import = array_merge( $extender_pro_labels, $extender_pro_import['extender_pro_labels'] );
					update_option( extender_pro_theme_option_name( 'custom_labels' ), $labels_import );
					
				}
				
			}
			
			if ( ! empty( $conditionals ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_conditionals'] ) ) {
					
					$extender_pro_conditionals_array = array();
					foreach( $extender_pro_conditionals as $key => $value ) {
						
						$extender_pro_conditionals_array[] = $extender_pro_conditionals[$key]['conditional_id'];
						
					}
					foreach( $extender_pro_import['extender_pro_conditionals'] as $key => $value ) {
						
						if ( in_array( $extender_pro_import['extender_pro_conditionals'][$key]['conditional_id'], $extender_pro_conditionals_array ) )
							unset( $extender_pro_import['extender_pro_conditionals'][$key] );
	
					}
					$conditionals_import = array_merge( $extender_pro_conditionals, $extender_pro_import['extender_pro_conditionals'] );
					update_option( extender_pro_theme_option_name( 'custom_conditionals' ), $conditionals_import );
					
				}
				
			}
			
			if ( ! empty( $widget_areas ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_widgets'] ) ) {
					
					$extender_pro_widgets_array = array();
					foreach( $extender_pro_widgets as $key => $value ) {
						
						if ( !in_array( $extender_pro_widgets[$key]['widget_name'], $extender_pro_widgets_array ) )
							$extender_pro_widgets_array[] = $extender_pro_widgets[$key]['widget_name'];
	
					}
					foreach( $extender_pro_import['extender_pro_widgets'] as $key => $value ) {
						
						if ( in_array( $extender_pro_import['extender_pro_widgets'][$key]['widget_name'], $extender_pro_widgets_array ) )
							unset( $extender_pro_import['extender_pro_widgets'][$key] );
	
					}
					$widgets_import = array_merge( $extender_pro_widgets, $extender_pro_import['extender_pro_widgets'] );
					update_option( extender_pro_theme_option_name( 'custom_widget_areas' ), $widgets_import );
					
				}
				
			}
			
			if ( ! empty( $hook_boxes ) ) {
				
				if ( ! empty( $extender_pro_import['extender_pro_hooks'] ) ) {
					
					$extender_pro_hooks_array = array();
					foreach( $extender_pro_hooks as $key => $value ) {
						
						if ( !in_array( $extender_pro_hooks[$key]['hook_name'], $extender_pro_hooks_array ) )
							$extender_pro_hooks_array[] = $extender_pro_hooks[$key]['hook_name'];
	
					}
					foreach( $extender_pro_import['extender_pro_hooks'] as $key => $value ) {
						
						if ( in_array( $extender_pro_import['extender_pro_hooks'][$key]['hook_name'], $extender_pro_hooks_array ) )
							unset( $extender_pro_import['extender_pro_hooks'][$key] );
	
					}
					$hooks_import = array_merge( $extender_pro_hooks, $extender_pro_import['extender_pro_hooks'] );
					update_option( extender_pro_theme_option_name( 'custom_hook_boxes' ), $hooks_import );
					
				}
				
			}
			
		}
			
		if ( ! empty( $images ) && file_exists( $tmp_import_folder . '/images' ) )
			extender_pro_copy_dir( $tmp_import_folder . '/images', extender_pro_get_stylesheet_location( 'path' ) . 'images' );
		
		extender_pro_delete_dir( $tmp_path );
		extender_pro_write_files();
		wp_redirect( admin_url( 'admin.php?page=extender-pro-import-export&notice=import-complete' ) );
		exit();
		
	} elseif ( 'dat' == strtolower( substr( strrchr( $import_file['name'], '.' ), 1 ) ) ) {
		
		$import_data = file_get_contents( $import_file['tmp_name'] );
		$extender_pro_import = unserialize( $import_data );
		
		if ( ! empty( $theme_settings ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_settings'] ) ) {
				
				$plugin_settings_import = array_merge( extender_pro_settings_defaults( false, $extender_pro_import['extender_pro_settings'] ), $extender_pro_import['extender_pro_settings'] );
				update_option( 'extender_pro_settings', $plugin_settings_import );
				
			}
			
		}
		
		if ( ! empty( $custom_styles ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_custom_styles'] ) )
				update_option( extender_pro_theme_option_name( 'custom_styles' ), $extender_pro_import['extender_pro_custom_styles'] );
			
		}
		
		if ( ! empty( $custom_functions ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_custom_functions'] ) )
				update_option( extender_pro_theme_option_name( 'custom_functions' ), $extender_pro_import['extender_pro_custom_functions'] );
				
			if ( ! empty( $extender_pro_import['extender_pro_custom_frontend_functions'] ) )
				update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), $extender_pro_import['extender_pro_custom_frontend_functions'] );
			
		}

		if ( ! empty( $custom_scripts ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_custom_header_scripts'] ) )
				update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), $extender_pro_import['extender_pro_custom_header_scripts'] );
				
			if ( ! empty( $extender_pro_import['extender_pro_custom_footer_scripts'] ) )
				update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), $extender_pro_import['extender_pro_custom_footer_scripts'] );
			
		}

		if ( ! empty( $custom_templates ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_templates'] ) ) {
				
				$extender_pro_templates_array = array();
				foreach( $extender_pro_templates as $key => $value ) {
					
					if ( !in_array( $extender_pro_templates[$key]['template_file_name'], $extender_pro_templates_array ) )
						$extender_pro_templates_array[] = $extender_pro_templates[$key]['template_file_name'];

				}
				foreach( $extender_pro_import['extender_pro_templates'] as $key => $value ) {
					
					if ( in_array( $extender_pro_import['extender_pro_templates'][$key]['template_file_name'], $extender_pro_templates_array ) )
						unset( $extender_pro_import['extender_pro_templates'][$key] );

				}
				$templates_import = array_merge( $extender_pro_templates, $extender_pro_import['extender_pro_templates'] );
				update_option( extender_pro_theme_option_name( 'custom_templates' ), $templates_import );
				
			}
			
		}

		if ( ! empty( $custom_labels ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_labels'] ) ) {
				
				$extender_pro_labels_array = array();
				foreach( $extender_pro_labels as $key => $value ) {
					
					if ( !in_array( $extender_pro_labels[$key]['label_name'], $extender_pro_labels_array ) )
						$extender_pro_labels_array[] = $extender_pro_labels[$key]['label_name'];
						
				}
				foreach( $extender_pro_import['extender_pro_labels'] as $key => $value ) {
					
					if ( in_array( $extender_pro_import['extender_pro_labels'][$key]['label_name'], $extender_pro_labels_array ) )
						unset( $extender_pro_import['extender_pro_labels'][$key] );

				}
				$labels_import = array_merge( $extender_pro_labels, $extender_pro_import['extender_pro_labels'] );
				update_option( extender_pro_theme_option_name( 'custom_labels' ), $labels_import );
				
			}
			
		}
		
		if ( ! empty( $conditionals ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_conditionals'] ) ) {
				
				$extender_pro_conditionals_array = array();
				foreach( $extender_pro_conditionals as $key => $value ) {
					
					$extender_pro_conditionals_array[] = $extender_pro_conditionals[$key]['conditional_id'];
					
				}
				foreach( $extender_pro_import['extender_pro_conditionals'] as $key => $value ) {
					
					if ( in_array( $extender_pro_import['extender_pro_conditionals'][$key]['conditional_id'], $extender_pro_conditionals_array ) )
						unset( $extender_pro_import['extender_pro_conditionals'][$key] );

				}
				$conditionals_import = array_merge( $extender_pro_conditionals, $extender_pro_import['extender_pro_conditionals'] );
				update_option( extender_pro_theme_option_name( 'custom_conditionals' ), $conditionals_import );
				
			}
			
		}
		
		if ( ! empty( $widget_areas ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_widgets'] ) ) {
				
				$extender_pro_widgets_array = array();
				foreach( $extender_pro_widgets as $key => $value ) {
					
					if ( !in_array( $extender_pro_widgets[$key]['widget_name'], $extender_pro_widgets_array ) )
						$extender_pro_widgets_array[] = $extender_pro_widgets[$key]['widget_name'];

				}
				foreach( $extender_pro_import['extender_pro_widgets'] as $key => $value ) {
					
					if ( in_array( $extender_pro_import['extender_pro_widgets'][$key]['widget_name'], $extender_pro_widgets_array ) )
						unset( $extender_pro_import['extender_pro_widgets'][$key] );

				}
				$widgets_import = array_merge( $extender_pro_widgets, $extender_pro_import['extender_pro_widgets'] );
				update_option( extender_pro_theme_option_name( 'custom_widget_areas' ), $widgets_import );
				
			}
			
		}
		
		if ( ! empty( $hook_boxes ) ) {
			
			if ( ! empty( $extender_pro_import['extender_pro_hooks'] ) ) {
				
				$extender_pro_hooks_array = array();
				foreach( $extender_pro_hooks as $key => $value ) {
					
					if ( !in_array( $extender_pro_hooks[$key]['hook_name'], $extender_pro_hooks_array ) )
						$extender_pro_hooks_array[] = $extender_pro_hooks[$key]['hook_name'];

				}
				foreach( $extender_pro_import['extender_pro_hooks'] as $key => $value ) {
					
					if ( in_array( $extender_pro_import['extender_pro_hooks'][$key]['hook_name'], $extender_pro_hooks_array ) )
						unset( $extender_pro_import['extender_pro_hooks'][$key] );

				}
				$hooks_import = array_merge( $extender_pro_hooks, $extender_pro_import['extender_pro_hooks'] );
				update_option( extender_pro_theme_option_name( 'custom_hook_boxes' ), $hooks_import );
				
			}
			
		}
		
		extender_pro_write_files();
		wp_redirect( admin_url( 'admin.php?page=extender-pro-import-export&notice=import-complete' ) );
		exit();

	} else {
		
		wp_redirect( admin_url( 'admin.php?page=extender-pro-import-export&notice=import-error' ) );
		exit();
		
	}
	
}

/**
 * Import the Custom Options from previous iterations
 * of the Extender Plugins.
 *
 * @since 1.0.0
 */
function extender_pro_old_custom_import() {
	
	if ( get_option( extender_pro_old_custom_option_name( 'custom_css' ) ) ) {
		
		$custom_css = get_option( extender_pro_old_custom_option_name( 'custom_css' ) );
		update_option( extender_pro_theme_option_name( 'custom_styles' ), $custom_css['custom_css'] );
		
	}

	if ( get_option( extender_pro_old_custom_option_name( 'custom_functions' ) ) ) {
		
		$custom_functions = get_option( extender_pro_old_custom_option_name( 'custom_functions' ) );
		if ( $custom_functions['custom_functions_effect_admin'] ) {
			
			update_option( extender_pro_theme_option_name( 'custom_functions' ), $custom_functions['custom_functions'] );
			update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your front-end functions below. (These functions affect front-end only.) */' . "\n" );
			
		} else {
			
			update_option( extender_pro_theme_option_name( 'custom_frontend_functions' ), $custom_functions['custom_functions'] );
			update_option( extender_pro_theme_option_name( 'custom_functions' ), '<?php' . "\n" . '/* Do not remove this line. Add your functions below. (NOTE: These functions affect both front-end AND admin.) */' . "\n" );
			
		}
		
	}
	
	if ( get_option( extender_pro_old_custom_option_name( 'custom_js' ) ) ) {
		
		$custom_js = get_option( extender_pro_old_custom_option_name( 'custom_js' ) );
		if ( $custom_js['custom_js_in_head'] ) {
			
			update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), $custom_js['custom_js'] );
			update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), '' );
			
		} else {
			
			update_option( extender_pro_theme_option_name( 'custom_footer_scripts' ), $custom_js['custom_js'] );
			update_option( extender_pro_theme_option_name( 'custom_header_scripts' ), '' );
			
		}
		
	}

	if ( get_option( extender_pro_old_custom_option_name( 'custom_templates' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_templates' ), get_option( extender_pro_old_custom_option_name( 'custom_templates' ) ) );

	if ( get_option( extender_pro_old_custom_option_name( 'custom_labels' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_labels' ), get_option( extender_pro_old_custom_option_name( 'custom_labels' ) ) );

	if ( get_option( extender_pro_old_custom_option_name( 'custom_conditionals' ) ) ) {
		
		if ( extender_pro_old_custom_option_name( $option, $extender_name_only = true ) == 'genesis_extender' )
			$has_label = str_replace( 'genesis_', '', extender_pro_old_custom_option_name( $option, $extender_name_only = true ) ) . '_has_label';
		else
			$has_label = extender_pro_old_custom_option_name( $option, $extender_name_only = true ) . '_has_label';
		
		$custom_conditionals = get_option( extender_pro_old_custom_option_name( 'custom_conditionals' ) );
		foreach( $custom_conditionals as $key => $value )
			$custom_conditionals[$key] = str_replace( $has_label, 'extender_pro_has_label', $value );
		
		update_option( extender_pro_theme_option_name( 'custom_conditionals' ), $custom_conditionals );
		
	}

	if ( get_option( extender_pro_old_custom_option_name( 'custom_widget_areas' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_widget_areas' ), get_option( extender_pro_old_custom_option_name( 'custom_widget_areas' ) ) );

	if ( get_option( extender_pro_old_custom_option_name( 'custom_hook_boxes' ) ) )
		update_option( extender_pro_theme_option_name( 'custom_hook_boxes' ), get_option( extender_pro_old_custom_option_name( 'custom_hook_boxes' ) ) );
		
	extender_pro_write_files();
	wp_redirect( admin_url( 'admin.php?page=extender-pro-import-export&notice=import-complete' ) );
	exit();
	
}

add_action( 'admin_init', 'extender_pro_import_export_check' );
/**
 * Check for Import/Export $_POST actions and react appropriately.
 *
 * @since 1.0.0
 */
function extender_pro_import_export_check() {
	
	if ( current_user_can( 'manage_options' ) ) {
	
		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'extender_pro_custom_export' ) {
			
			$export_name = $_POST['extender_pro_export_name'] != '' ? $_POST['extender_pro_export_name'] : false;
			$theme_settings = isset( $_POST['export_settings'] ) ? $_POST['export_settings'] : '';
			$custom_styles = isset( $_POST['export_styles'] ) ? $_POST['export_styles'] : '';
			$custom_functions = isset( $_POST['export_functions'] ) ? $_POST['export_functions'] : '';
			$custom_scripts = isset( $_POST['export_scripts'] ) ? $_POST['export_scripts'] : '';
			$custom_templates = isset( $_POST['export_templates'] ) ? $_POST['export_templates'] : '';
			$custom_labels = isset( $_POST['export_labels'] ) ? $_POST['export_labels'] : '';
			$conditionals = isset( $_POST['export_conditionals'] ) ? $_POST['export_conditionals'] : '';
			$widget_areas = isset( $_POST['export_widgets'] ) ? $_POST['export_widgets'] : '';
			$hook_boxes = isset( $_POST['export_hooks'] ) ? $_POST['export_hooks'] : '';
			$images = isset( $_POST['export_images'] ) ? $_POST['export_images'] : '';
	
			extender_pro_custom_export( $export_name, $theme_settings, $custom_styles, $custom_functions, $custom_scripts, $custom_templates, $custom_labels, $conditionals, $widget_areas, $hook_boxes, $images );
			
		}
		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'extender_pro_custom_import' ) {
			
			$theme_settings = isset( $_POST['import_settings'] ) ? $_POST['import_settings'] : '';
			$custom_styles = isset( $_POST['import_styles'] ) ? $_POST['import_styles'] : '';
			$custom_functions = isset( $_POST['import_functions'] ) ? $_POST['import_functions'] : '';
			$custom_scripts = isset( $_POST['import_scripts'] ) ? $_POST['import_scripts'] : '';
			$custom_templates = isset( $_POST['import_templates'] ) ? $_POST['import_templates'] : '';
			$custom_labels = isset( $_POST['import_labels'] ) ? $_POST['import_labels'] : '';
			$conditionals = isset( $_POST['import_conditionals'] ) ? $_POST['import_conditionals'] : '';
			$widget_areas = isset( $_POST['import_widgets'] ) ? $_POST['import_widgets'] : '';
			$hook_boxes = isset( $_POST['import_hooks'] ) ? $_POST['import_hooks'] : '';
			$images = isset( $_POST['import_images'] ) ? $_POST['import_images'] : '';
			
			extender_pro_custom_import( $_FILES['custom_import_file'], $theme_settings, $custom_styles, $custom_functions, $custom_scripts, $custom_templates, $custom_labels, $conditionals, $widget_areas, $hook_boxes, $images );
		
		}
		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'extender_pro_old_custom_import' )
			extender_pro_old_custom_import();
		
	}
	
}

/**
 * Build the appropriate full get option text for custom options
 * of previous iterations of the Extender Plugins.
 *
 * @since 1.0.0
 * @return the appropriate full get option text for custom options.
 */
function extender_pro_old_custom_option_name( $option, $extender_name_only = false ) {
	
	if ( extender_pro_active_theme_name() == 'bb-theme' )
		$extender_name = 'beaver_extender';
	elseif ( extender_pro_active_theme_name() == 'freelancer' )
		$extender_name = 'freelancer_extender';
	elseif ( extender_pro_active_theme_name() == 'generatepress' )
		$extender_name = 'gp_extender';
	elseif ( extender_pro_active_theme_name() == 'genesis' )
		$extender_name = 'genesis_extender';
	elseif ( extender_pro_active_theme_name() == 'oceanwp' )
		$extender_name = 'oceanwp_extender';
	
	if ( false !== $extender_name_only )
		$name = $extender_name;
	else
		$name = $extender_name . '_' . $option;
	
	return $name;
    
}
