<?php
/**
 * Builds the functions required to create, update, delete and display
 * Custom Labels in Custom Options.
 *
 * @package Extender Pro
 */

/**
 * Get Custom Labels from the database, if any exist, and then return
 * them in a sorted array.
 *
 * @since 1.0.0
 * @return soreted array of all Custom Labels from the database if they exist.
 */
function extender_pro_get_labels() {
	
	$custom_labels = get_option( extender_pro_theme_option_name( 'custom_labels' ) );
	
	if ( ! empty( $custom_labels ) ) {
		
		$custom_labels = extender_pro_array_sort( $custom_labels, 'label_name' );		
		return $custom_labels;
		
	} else {
		
		return false;
		
	}
	
}

/**
 * Update Custom Labels in the database from current settings posted
 * in the Custom Options > Custom Labels admin page.
 *
 * @since 1.0.0
 */
function extender_pro_update_labels( $label_names = '' ) {
	
	$these_labels = array();
	$label_name_array = array();
	
	if ( ! empty( $label_names[1] ) ) {
		
		foreach( $label_names as $key => $value ) {
			
			$these_labels[$key]['label_name'] = $value;
			
		}
		
	}

	if ( ! empty( $these_labels ) ) {
		
		foreach( $these_labels as $this_label ) {
			
			$extender_pro_labels = get_option( extender_pro_theme_option_name( 'custom_labels' ) );
			$label_name = $this_label['label_name'];
			$label_id = extender_pro_sanitize_string( $label_name );
			
			if ( ! empty( $label_name ) ) {
				
				$new_values = array( $label_id => array( 'label_id' => $label_id, 'label_name' => $label_name ) );
				$merged_page_label = array_merge( $extender_pro_labels, $new_values );
				update_option( extender_pro_theme_option_name( 'custom_labels' ), $merged_page_label );
				
			}
			
		}
		
	}
	
}

/**
 * Delete Custom Labels from the database that are posted for deletion
 * in Custom Options > Custom Labels.
 *
 * @since 1.0.0
 */
add_action( 'wp_ajax_extender_pro_label_delete', 'extender_pro_delete_label' );
function extender_pro_delete_label() {
	
	$extender_pro_labels = get_option( extender_pro_theme_option_name( 'custom_labels' ) );
	
	$label_name = $_POST['label_name'];
	
	foreach( $extender_pro_labels as $key => $value ) {
		
		if ( in_array( $label_name, $extender_pro_labels[$key] ) ) {
			
			unset( $extender_pro_labels[$key] );
			
		}
		
	}

	update_option( extender_pro_theme_option_name( 'custom_labels' ), $extender_pro_labels );
		
	echo 'deleted';
	
}
