<?php
/**
 * Builds many of the admin options drop-down lists.
 *
 * @package Extender Pro
 */
 
/**
 * Build an options list of active theme hooks.
 *
 * @since 1.0.0
 */
function extender_pro_list_hooks( $selected = '' ) {
	
	if ( defined( 'ASTRA_THEME_VERSION' ) )
		$hooks = extender_pro_astra_hooks_list();
	elseif ( defined( 'FL_THEME_VERSION' ) )
		$hooks = extender_pro_bb_theme_hooks_list();
	elseif ( defined( 'FREELANCER_PARENT_THEME_NAME' ) )
		$hooks = extender_pro_freelancer_hooks_list();
	elseif ( defined( 'GENERATE_VERSION' ) )
		$hooks = extender_pro_generatepress_hooks_list();
	elseif ( defined( 'PARENT_THEME_NAME' ) && PARENT_THEME_NAME == 'Genesis' )
		$hooks = extender_pro_genesis_hooks_list();
	elseif ( defined( 'OCEANWP_THEME_VERSION' ) )
		$hooks = extender_pro_oceanwp_hooks_list();
	
	extender_pro_build_hooks_select_menu( $hooks, $selected );
	
}

/**
 * Return an array of Astra Theme hooks.
 *
 * @since 1.0.0
 * @return an array of Astra Theme hooks.
 */
function extender_pro_astra_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
            'astra_html_before',
            'astra_head_top',
            'astra_head_bottom',
            'wp_head',
		),
		'-- Page Hooks --' => array(
			'astra_body_top',
			'astra_body_bottom',
		),
		'-- Header Hooks --' => array(
            'astra_header_before',
            'astra_header_after',
            'astra_masthead_top',
            'astra_masthead_bottom',
            'astra_main_header_bar_top',
            'astra_main_header_bar_bottom',
            'astra_masthead_content',
            'astra_masthead_toggle_buttons_before',
            'astra_masthead_toggle_buttons_after',
		),
		'-- Content Hooks --' => array(
            'astra_content_before',
            'astra_content_after',
            'astra_content_top',
            'astra_content_bottom',
            'astra_primary_content_top',
            'astra_primary_content_bottom',
            'astra_entry_before',
            'astra_entry_after',
            'astra_entry_top',
            'astra_entry_bottom',
            'astra_single_header_before',
            'astra_single_header_after',
            'astra_single_header_top',
            'astra_single_header_bottom',
            'astra_entry_content_before',
            'astra_entry_content_after',
		),
		'-- Loop Hooks --' => array(
			'astra_content_while_before',
		    'astra_content_while_after',
		),
		'-- Comment Hooks --' => array(
            'astra_comments_before',
            'astra_comments_after',
		),
		'-- Sidebar Hooks --' => array(
            'astra_sidebars_before',
            'astra_sidebars_after',
		),
		'-- Footer Hooks --' => array(
            'astra_footer_before',
            'astra_footer_after',
            'astra_footer_content_top',
            'astra_footer_content_bottom',
            'wp_footer',
		),
	);
	
	return $hooks;
	
}

/**
 * Return an array of BB Theme Theme hooks.
 *
 * @since 1.0.0
 * @return an array of BB Theme Theme hooks.
 */
function extender_pro_bb_theme_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
			'fl_head_open',
			'fl_head',
			'wp_head',
		),
		'-- Page Hooks --' => array(
			'fl_body_open',
			'fl_body_close',
			'fl_page_open',
			'fl_page_close',
			'fl_before_top_bar',
			'fl_after_top_bar',
			'fl_top_bar_col1_open',
			'fl_top_bar_col1_close',
			'fl_top_bar_col2_open',
			'fl_top_bar_col2_close',
		),
		'-- Header Hooks --' => array(
			'fl_before_header',
			'fl_after_header',
			'fl_header_content_open',
			'fl_header_content_close',
		),
		'-- Content Hooks --' => array(
			'fl_before_content',
			'fl_after_content',
			'fl_content_open',
			'fl_content_close',
			'fl_post_top_meta_open',
			'fl_post_top_meta_close',
			'fl_post_bottom_meta_open',
			'fl_post_bottom_meta_close',
		),
		'-- Comment Hooks --' => array(
			'fl_comments_open',
			'fl_comments_close',
		),
		'-- Sidebar Hooks --' => array(
			'fl_sidebar_open',
			'fl_sidebar_close',
		),
		'-- Footer Hooks --' => array(
			'fl_footer_wrap_open',
			'fl_footer_wrap_close',
			'fl_before_footer_widgets',
			'fl_after_footer_widgets',
			'fl_before_footer',
			'fl_after_footer',
			'fl_footer_col1_open',
			'fl_footer_col1_close',
			'fl_footer_col2_open',
			'fl_footer_col2_close',
			'wp_footer',
		)
	);
	
	return $hooks;
	
}

/**
 * Return an array of Freelancer Theme hooks.
 *
 * @since 1.0.0
 * @return an array of Freelancer Theme hooks.
 */
function extender_pro_freelancer_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
			'freelancer_head',
			'freelancer_in_head',
			'wp_head',
		),
		'-- Page Hooks --' => array(
			'freelancer_before',
			'freelancer_after',
		),
		'-- Header Hooks --' => array(
			'freelancer_before_header',
			'freelancer_header',
			'freelancer_after_header',
			'freelancer_in_header',
			'freelancer_in_header_main',
			'freelancer_site_branding_logo',
			'freelancer_site_branding_text',
			'freelancer_site_title',
			'freelancer_site_description',
			'freelancer_in_header_menu',
		),
		'-- Content Hooks --' => array(
			'freelancer_before_site_content',
			'freelancer_after_site_content',
			'freelancer_before_content_area',
			'freelancer_after_content_area',
			'freelancer_before_content',
			'freelancer_after_content',
			'freelancer_before_entry',
			'freelancer_after_entry',
			'freelancer_entry_header',
			'freelancer_inside_entry_header',
			'freelancer_post_meta_top',
			'freelancer_before_entry_content',
			'freelancer_entry_content',
			'freelancer_after_entry_content',
			'freelancer_entry_footer',
			'freelancer_inside_entry_footer',
			'freelancer_post_meta_bottom',
			'freelancer_404_entry_content',
			'freelancer_no_entry_content',
		),
		'-- Loop Hooks --' => array(
		    'freelancer_before_while',
			'freelancer_before_loop',
			'freelancer_loop',
			'freelancer_after_loop',
			'freelancer_after_endwhile',
			'freelancer_loop_else',
		),
		'-- Comment Hooks --' => array(
			'freelancer_before_comments',
			'freelancer_comments',
			'freelancer_after_comments',
			'freelancer_before_comment_form',
			'freelancer_comment_form',
			'freelancer_after_comment_form',
		),
		'-- Sidebar Hooks --' => array(
			'freelancer_before_sidebar',
			'freelancer_sidebar',
			'freelancer_after_sidebar',
		),
		'-- Footer Hooks --' => array(
			'freelancer_before_footer',
			'freelancer_footer',
			'freelancer_after_footer',
			'freelancer_in_footer',
			'freelancer_credits',
			'wp_footer',
		),
	);
	
	return $hooks;
	
}

/**
 * Return an array of GeneratePress Theme hooks.
 *
 * @since 1.0.0
 * @return an array of GeneratePress Theme hooks.
 */
function extender_pro_generatepress_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
			'wp_head',
		),
		'-- Header Hooks --' => array(
			'generate_before_header',
			'generate_after_header',
			'generate_header',
			'generate_before_header_content',
			'generate_after_header_content',
			'generate_inside_mobile_header',
		),
		'-- Menu Hooks --' => array(
			'generate_inside_navigation',
			'generate_inside_secondary_navigation',
			'generate_inside_slideout_navigation',
			'generate_inside_mobile_header_menu',
			'generate_inside_mobile_menu_bar',
			'generate_inside_mobile_menu',
			'generate_inside_secondary_mobile_menu',
		),
		'-- Content Hooks --' => array(
			'generate_inside_container',
			'generate_before_main_content',
			'generate_after_main_content',
			'generate_before_content',
			'generate_after_content',
			'generate_after_primary_content_area',
			'generate_after_entry_title',
			'generate_after_entry_header',
			'generate_after_entry_content',
			'generate_before_archive_title',
			'generate_after_archive_title',
			'generate_archive_title',
			'generate_after_archive_description',
			'generate_paging_navigation',
		),
		'-- Comment Hooks --' => array(
			'generate_before_comments',
			'generate_inside_comments',
		),
		'-- Sidebar Hooks --' => array(
			'generate_sidebars',
			'generate_before_left_sidebar_content',
			'generate_after_left_sidebar_content',
			'generate_before_right_sidebar_content',
			'generate_after_right_sidebar_content',
		),
		'-- Footer Hooks --' => array(
			'generate_before_footer',
			'generate_before_footer_content',
			'generate_after_footer_content',
			'generate_after_footer_widgets',
			'generate_before_copyright',
			'generate_credits',
			'wp_footer',
		)
	);
	
	return $hooks;
	
}

/**
 * Return an array of Genesis Theme hooks.
 *
 * @since 1.0.0
 * @return an array of Genesis Theme hooks.
 */
function extender_pro_genesis_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
			'genesis_doctype',
			'genesis_title',
			'genesis_meta',
			'wp_head',
		),
		'-- Page Hooks --' => array(
			'genesis_before',
			'genesis_after',	
		),
		'-- Header Hooks --' => array(
			'genesis_before_header',
			'genesis_header',
			'genesis_after_header',
			'genesis_site_title',
			'genesis_site_description',
			'genesis_header_right',
		),
		'-- Content Hooks --' => array(
			'genesis_before_content_sidebar_wrap',
			'genesis_after_content_sidebar_wrap',
			'genesis_before_content',
			'genesis_after_content',
		),
		'-- HTML5 Content Hooks --' => array(
			'genesis_before_entry',
			'genesis_after_entry',
			'genesis_entry_header',
			'genesis_before_entry_content',
			'genesis_entry_content',
			'genesis_after_entry_content',
			'genesis_entry_footer',
		),
		'-- XHTML Content Hooks --' => array(
			'genesis_before_post',
			'genesis_after_post',
			'genesis_before_post_title',
			'genesis_post_title',
			'genesis_after_post_title',
			'genesis_before_post_content',
			'genesis_post_content',
			'genesis_after_post_content',
		),
		'-- Loop Hooks --' => array(
			'genesis_before_loop',
			'genesis_loop',
			'genesis_after_loop',
			'genesis_after_endwhile',
			'genesis_loop_else',
		),
		'-- Comment Hooks --' => array(
			'genesis_before_comments',
			'genesis_comments',
			'genesis_after_comments',
			'genesis_list_comments',
			'genesis_before_pings',
			'genesis_pings',
			'genesis_after_pings',
			'genesis_before_comment',
			'genesis_after_comment',
			'genesis_before_comment_form',
			'genesis_comment_form',
			'genesis_after_comment_form',
		),
		'-- Sidebar Hooks --' => array(
			'genesis_sidebar',
			'genesis_before_sidebar_widget_area',
			'genesis_after_sidebar_widget_area',
			'genesis_sidebar_alt',
			'genesis_before_sidebar_alt_widget_area',
			'genesis_after_sidebar_alt_widget_area',
		),
		'-- Footer Hooks --' => array(
			'genesis_before_footer',
			'genesis_footer',
			'genesis_after_footer',
			'wp_footer',
		)
	);
	
	return $hooks;
	
}

/**
 * Return an array of OceanWP Theme hooks.
 *
 * @since 1.0.0
 * @return an array of OceanWP Theme hooks.
 */
function extender_pro_oceanwp_hooks_list() {
	
	$hooks = array(
		'-- <head> Hooks --' => array(
			'wp_head',
		),
		'-- Page Hooks --' => array(
			'ocean_before_outer_wrap',
			'ocean_after_outer_wrap',
			'ocean_before_wrap',
			'ocean_after_wrap',
		),
		'-- Top Bar Hooks --' => array(
			'ocean_before_top_bar',
			'ocean_after_top_bar',
			'ocean_before_top_bar_inner',
			'ocean_after_top_bar_inner',
		),
		'-- Header Hooks --' => array(
			'ocean_before_header',
			'ocean_after_header',
			'ocean_before_header_inner',
			'ocean_after_header_inner',
			'ocean_before_logo',
			'ocean_after_logo',
			'ocean_before_logo_inner',
			'ocean_after_logo_inner',
		),
		'-- Header Menu Hooks --' => array(
			'ocean_before_nav',
			'ocean_after_nav',
			'ocean_before_nav_inner',
			'ocean_after_nav_inner',
		),
		'-- Page Header Hooks --' => array(
			'ocean_before_page_header',
			'ocean_after_page_header',
			'ocean_before_page_header_inner',
			'ocean_after_page_header_inner',
		),
		'-- Content Hooks --' => array(
			'ocean_before_main',
			'ocean_after_main',
			'ocean_before_content_wrap',
			'ocean_before_content_wrap',
			'ocean_before_primary',
			'ocean_after_primary',
			'ocean_before_content',
			'ocean_after_content',
			'ocean_before_content_inner',
			'ocean_after_content_inner',
			'ocean_before_page_entry',
			'ocean_after_page_entry',
			'ocean_before_blog_entry_title',
			'ocean_after_blog_entry_title',
			'ocean_before_blog_entry_meta',
			'ocean_after_blog_entry_meta',
			'ocean_before_blog_entry_content',
			'ocean_after_blog_entry_content',
			'ocean_before_blog_entry_readmore',
			'ocean_after_blog_entry_readmore',
			'ocean_before_single_post_title',
			'ocean_after_single_post_title',
			'ocean_before_single_post_meta',
			'ocean_after_single_post_meta',
			'ocean_before_single_post_content',
			'ocean_after_single_post_content',
			'ocean_before_single_post_next_prev',
			'ocean_after_single_post_next_prev',
			'ocean_before_single_post_related_posts',
			'ocean_after_single_post_related_posts',
		),
		'-- Product Hooks --' => array(
			'ocean_before_single_product_title',
			'ocean_after_single_product_title',
			'ocean_before_single_product_meta',
			'ocean_after_single_product_meta',
			'ocean_before_single_product_excerpt',
			'ocean_after_single_product_excerpt',
			'ocean_before_single_product_price',
			'ocean_after_single_product_price',
			'ocean_before_single_product_rating',
			'ocean_after_single_product_rating',
			'ocean_before_single_product_quantity-button',
			'ocean_after_single_product_quantity-button',
			'ocean_before_archive_product_title',
			'ocean_after_archive_product_title',
			'ocean_before_archive_product_inner',
			'ocean_after_archive_product_inner',
			'ocean_before_archive_product_item',
			'ocean_after_archive_product_item',
			'ocean_before_archive_product_image',
			'ocean_after_archive_product_image',
			'ocean_before_archive_product_add_to_cart',
			'ocean_after_archive_product_add_to_cart',
			'ocean_before_archive_product_description',
			'ocean_after_archive_product_description',
			'ocean_before_archive_product_categories',
			'ocean_after_archive_product_categories',
		),
		'-- Author Bio --' => array(
			'ocean_before_single_post_author_bio',
			'ocean_after_single_post_author_bio',
		),
		'-- Sidebar Hooks --' => array(
			'ocean_before_sidebar',
			'ocean_after_sidebar',
			'ocean_before_sidebar_inner',
			'ocean_after_sidebar_inner',
		),
		'-- Footer Hooks --' => array(
			'ocean_before_footer',
			'ocean_after_footer',
			'ocean_before_footer_inner',
			'ocean_after_footer_inner',
			'ocean_before_footer_widgets',
			'ocean_after_footer_widgets',
			'ocean_before_footer_widgets_inner',
			'ocean_after_footer_widgets_inner',
			'ocean_before_footer_bottom',
			'ocean_after_footer_bottom',
			'ocean_before_footer_bottom_inner',
			'ocean_after_footer_bottom_inner',
			'wp_footer',
		)
	);
	
	return $hooks;
	
}

/**
 * Builds the active theme hooks list select menu.
 *
 * @since 1.0.0
 */
function extender_pro_build_hooks_select_menu( $hooks, $selected = '' ) {
	
	foreach( $hooks as $optgroup => $options ) {
		
		echo '<optgroup style="font-size:14px;color:#57A18D;" label="' . $optgroup . '">';
		foreach( $options as $option ) {
			
			$output = '<option style="color:#000000;" value="' . $option . '"';
				
			if ( $option == $selected )
				$output .= ' selected="selected"';

			$output .= '>' . $option . '</option>';
			
			echo $output;
		}
		echo '</optgroup>';
		
	}
	
}

/**
 * Build Custom Conditional Examples options list.
 *
 * @since 1.0.0
 */
function extender_pro_list_conditional_examples( $selected = '' ) {
	
	$extender_pro_conditional_examples = array(
		'examples' => 'Examples:',
		'is_page|is_page()' => 'Is Page',
		'is_not_page|! is_page()' => 'Is NOT Page',
		'is_page_template|is_page_template()' => 'Is Page Template',
		'is_not_page_template|! is_page_template()' => 'Is NOT Page Template',
		'is_single_post|is_single()' => 'Is Single Post',
		'is_not_single_post|! is_single()' => 'Is NOT Single Post',
		'is_front_page|is_front_page()' => 'Is Front Page',
		'is_not_front_page|! is_front_page()' => 'Is NOT Front Page',
		'is_archive|is_archive()' => 'Is Archive',
		'is_not_archive|! is_archive()' => 'Is NOT Archive',
		'is_category|is_category()' => 'Is Category',
		'is_not_category|! is_category()' => 'Is NOT Category',
		'is_tag|is_tag()' => 'Is Tag',
		'is_not_tag|! is_tag()' => 'Is NOT Tag',
		'is_author|is_author()' => 'Is Author',
		'is_not_author|! is_author()' => 'Is NOT Author',
		'has_label_example|extender_pro_has_label(&#39;example&#39;)' => 'Has Extender Label'
	);
	
	foreach( $extender_pro_conditional_examples as $conditional_examples_key => $conditional_examples_name ) {
		
		$option = '<option value="' . $conditional_examples_key . '"';
			
		if ( $conditional_examples_key == $selected )
			$option .= ' selected="selected"';

		$option .= '>' . $conditional_examples_name . '</option>';
		
		echo $option;
		
	}
	
}
