<?php
/**
 * Locate, Write and Add various Extender Pro files.
 *
 * @package Extender Pro
 */
 
/**
 * Get the stylesheet location based on the type of stylesheet.
 *
 * @since 1.0.0
 * @return the stylesheet location.
 */
function extender_pro_get_stylesheet_location( $type, $root = false ) {
    
	$uploads = wp_upload_dir();
	
    if ( extender_pro_get_settings( 'enable_protocol_relative_urls' ) ) {
        
        $base_url = $uploads['baseurl'];
        $base_dir = $uploads['basedir'];
        $dir = ( 'url' == $type ) ? str_replace( 'http:', '', $base_url ) : $base_dir;
        
    } else {
        
        $dir = ( 'url' == $type ) ? $uploads['baseurl'] : $uploads['basedir'];
        
    }
    
	$sub_dir = $root ? '/extender-pro/' : '/extender-pro/' . extender_pro_active_theme_name() . '/';

	return apply_filters( 'extender_pro_get_stylesheet_location', $dir . $sub_dir );
	
}

/**
 * Get the stylesheet name based on the name value passed into the function.
 *
 * @since 1.0.0
 * @return the stylesheet name.
 */
function extender_pro_get_stylesheet_name( $slug='stylesheet' ) {
    
    return apply_filters( 'extender_pro_get_stylesheet_name', $slug . '.css' );
    
}

/**
 * Get the Custom stylesheet name.
 *
 * @since 1.0.0
 * @return the Custom stylesheet name.
 */
function extender_pro_get_custom_stylesheet_name() {
    
    return apply_filters( 'extender_pro_get_custom_stylesheet_name', extender_pro_get_stylesheet_name( 'custom' ) );
    
}

/**
 * Get the Custom stylesheet path.
 *
 * @since 1.0.0
 * @return the Custom stylesheet path.
 */
function extender_pro_get_custom_stylesheet_path() {
    
    return apply_filters( 'extender_pro_get_custom_stylesheet_path', extender_pro_get_stylesheet_location( 'path' ) . extender_pro_get_custom_stylesheet_name() );
    
}

/**
 * Get the Custom stylesheet url.
 *
 * @since 1.0.0
 * @return the Custom stylesheet url.
 */
function extender_pro_get_custom_stylesheet_url() {
    
    return apply_filters( 'extender_pro_get_custom_stylesheet_url', extender_pro_get_stylesheet_location( 'url' ) . extender_pro_get_custom_stylesheet_name() );
    
}

/**
 * Get the Minified stylesheet name.
 *
 * @since 1.0.0
 * @return the Minified stylesheet name.
 */
function extender_pro_get_minified_stylesheet_name() {
    
    return apply_filters( 'extender_pro_get_minified_stylesheet_name', extender_pro_get_stylesheet_name( 'custom.min' ) );
    
}

/**
 * Get the Minified stylesheet path.
 *
 * @since 1.0.0
 * @return the Minified stylesheet path.
 */
function extender_pro_get_minified_stylesheet_path() {
    
    return apply_filters( 'extender_pro_get_minified_stylesheet_path', extender_pro_get_stylesheet_location( 'path' ) . extender_pro_get_minified_stylesheet_name() );
    
}

/**
 * Get the Minified stylesheet url.
 *
 * @since 1.0.0
 * @return the Minified stylesheet url.
 */
function extender_pro_get_minified_stylesheet_url() {
    
    return apply_filters( 'extender_pro_get_minified_stylesheet_url', extender_pro_get_stylesheet_location( 'url' ) . extender_pro_get_minified_stylesheet_name() );
    
}

/**
 * Get the Extender Pro Custom Functions file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Functions file path.
 *
 */
function extender_pro_get_custom_functions_path() {
    
	return extender_pro_get_stylesheet_location( 'path' ) . 'custom-functions.php';
	
}

/**
 * Get the Extender Pro Custom Front-End Functions file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Front-End Functions file path.
 *
 */
function extender_pro_get_custom_frontend_functions_path() {
    
	return extender_pro_get_stylesheet_location( 'path' ) . 'custom-frontend-functions.php';
	
}

/**
 * Get the Extender Pro Custom Header Scripts file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Header Scripts file path.
 *
 */
function extender_pro_get_custom_header_scripts_path() {
    
    return extender_pro_get_stylesheet_location( 'path' ) . 'custom-header-scripts.js';
    
}

/**
 * Get the Extender Pro Custom Minified Header Scripts file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Minified Header Scripts file path.
 *
 */
function extender_pro_get_custom_minified_header_scripts_path() {
    
    return extender_pro_get_stylesheet_location( 'path' ) . 'custom-header-scripts.min.js';
    
}

/**
 * Get the Extender Pro Custom Footer Scripts file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Footer Scripts file path.
 *
 */
function extender_pro_get_custom_footer_scripts_path() {
    
    return extender_pro_get_stylesheet_location( 'path' ) . 'custom-footer-scripts.js';
    
}

/**
 * Get the Extender Pro Custom Minified Footer Scripts file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Minified Footer Scripts file path.
 *
 */
function extender_pro_get_custom_minified_footer_scripts_path() {
    
    return extender_pro_get_stylesheet_location( 'path' ) . 'custom-footer-scripts.min.js';
    
}

/**
 * Get the Extender Pro Custom Template file paths.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Template file paths.
 *
 */
function extender_pro_get_custom_template_paths( $template_file_name, $template_type ) {
    
    if ( $template_type == 'page_template' )
        return get_stylesheet_directory() . '/my-templates/' . $template_file_name . '.php';
    else
        return get_stylesheet_directory() . '/' . $template_file_name . '.php';
    
}

/**
 * Get the Extender Pro Custom Widget Areas Register file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Widget Areas Register file path.
 *
 */
function extender_pro_get_custom_widget_areas_register_path() {
    
	return extender_pro_get_stylesheet_location( 'path' ) . 'custom-widget-areas-register.php';
	
}

/**
 * Get the Extender Pro Custom Widget Areas file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Widget Areas file path.
 *
 */
function extender_pro_get_custom_widget_areas_path() {
    
	return extender_pro_get_stylesheet_location( 'path' ) . 'custom-widget-areas.php';
	
}

/**
 * Get the Extender Pro Custom Hook Boxes file path.
 *
 * @since 1.0.0
 * @return the Extender Pro Custom Hook Boxes file path.
 *
 */
function extender_pro_get_custom_hook_boxes_path() {
    
	return extender_pro_get_stylesheet_location( 'path' ) . 'custom-hook-boxes.php';
	
}
