<?php
/**
 * Locate, Write and Add various Extender Pro files.
 *
 * @package Extender Pro
 */
 
/**
 * Write the Custom stylesheet file.
 *
 * @since 1.0.0
 */
function extender_pro_write_custom_styles() {

	$css = stripslashes( get_option( extender_pro_theme_option_name( 'custom_styles' ) ) );
	
	$handle = @fopen( extender_pro_get_custom_stylesheet_path(), 'w' );
	@fwrite( $handle, $css );
	@fclose( $handle );
	if ( substr( sprintf( '%o', fileperms( extender_pro_get_custom_stylesheet_path() ) ), -4 ) != '0644' &&
		substr( sprintf( '%o', fileperms( extender_pro_get_custom_stylesheet_path() ) ), -4 ) != '0666' )
			@chmod( extender_pro_get_custom_stylesheet_path(), 0644 );
			
}

/**
 * Write the Minified stylesheet file.
 *
 * @since 1.0.0
 */
function extender_pro_write_minified_styles() {

	$css = extender_pro_minify_css( stripslashes( get_option( extender_pro_theme_option_name( 'custom_styles' ) ) ) );
	
	$handle = @fopen( extender_pro_get_minified_stylesheet_path(), 'w' );
	@fwrite( $handle, $css );
	@fclose( $handle );
	if ( substr( sprintf( '%o', fileperms( extender_pro_get_minified_stylesheet_path() ) ), -4 ) != '0644' &&
		substr( sprintf( '%o', fileperms( extender_pro_get_minified_stylesheet_path() ) ), -4 ) != '0666' )
			@chmod( extender_pro_get_minified_stylesheet_path(), 0644 );

}

/**
 * Create the Extender Pro Custom Functions file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_functions_file() {
	
	if ( file_exists( extender_pro_get_custom_functions_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_functions_path(), 'w' );
	@fwrite( $handle, stripslashes( '<?php' . "\n" . '/* Do not remove this line. Add your functions below. (NOTE: These functions affect both front-end AND admin.) */' . "\n" ) );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Functions file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_functions( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_functions_path() ) )
		extender_pro_create_custom_functions_file();

	$handle = @fopen( extender_pro_get_custom_functions_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Front-End Functions file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_frontend_functions_file() {
	
	if ( file_exists( extender_pro_get_custom_frontend_functions_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_frontend_functions_path(), 'w' );
	@fwrite( $handle, stripslashes( '<?php' . "\n" . '/* Do not remove this line. Add your front-end functions below. (These functions affect front-end only.) */' . "\n" ) );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Front-End Functions file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_frontend_functions( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_frontend_functions_path() ) )
		extender_pro_create_custom_frontend_functions_file();

	$handle = @fopen( extender_pro_get_custom_frontend_functions_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Header Scripts file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_header_scripts_file() {
	
	if ( file_exists( extender_pro_get_custom_header_scripts_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_header_scripts_path(), 'w' );
	@fwrite( $handle, '' );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Header Scripts file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_header_scripts( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_header_scripts_path() ) )
		extender_pro_create_custom_header_scripts_file();

	$handle = @fopen( extender_pro_get_custom_header_scripts_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Minified Header Scripts file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_minified_header_scripts_file() {
	
	if ( file_exists( extender_pro_get_custom_minified_header_scripts_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_minified_header_scripts_path(), 'w' );
	@fwrite( $handle, '' );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Minified Header Scripts file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_minified_header_scripts( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_minified_header_scripts_path() ) )
		extender_pro_create_custom_minified_header_scripts_file();
		
	$handle = @fopen( extender_pro_get_custom_minified_header_scripts_path(), 'w+' );
	@fwrite( $handle, extender_pro_minify_js( stripslashes( $code ) ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Footer Scripts file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_footer_scripts_file() {
	
	if ( file_exists( extender_pro_get_custom_footer_scripts_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_footer_scripts_path(), 'w' );
	@fwrite( $handle, '' );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Footer Scripts file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_footer_scripts( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_footer_scripts_path() ) )
		extender_pro_create_custom_footer_scripts_file();

	$handle = @fopen( extender_pro_get_custom_footer_scripts_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Minified Footer Scripts file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_minified_footer_scripts_file() {
	
	if ( file_exists( extender_pro_get_custom_minified_footer_scripts_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_minified_footer_scripts_path(), 'w' );
	@fwrite( $handle, '' );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Minified Footer Scripts file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_minified_footer_scripts( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_minified_footer_scripts_path() ) )
		extender_pro_create_custom_minified_footer_scripts_file();
		
	$handle = @fopen( extender_pro_get_custom_minified_footer_scripts_path(), 'w+' );
	@fwrite( $handle, extender_pro_minify_js( stripslashes( $code ) ) );
	@fclose( $handle );
	
}

/**
 * Create and write to the Extender Pro Custom Template files.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_templates() {
	
	$extender_pro_templates = get_option( extender_pro_theme_option_name( 'custom_templates' ) );
	
	if ( ! empty( $extender_pro_templates ) ) {
		
		extender_pro_dir_check( get_stylesheet_directory() . '/my-templates' );
		
		foreach( $extender_pro_templates as $extender_pro_template => $template_bits ) {
			
			if ( $template_bits['template_type'] == 'page_template' ) {
				$template_post_type = empty( $template_bits['template_post_type'] ) ? 'page' : $template_bits['template_post_type'];
				$extender_pro_template_content = '<?php
/*
 * Template Name: ' . $template_bits['template_name'] . '
 * Template Post Type: ' . $template_post_type . '
 */
?>
';
			} else {
				
				$extender_pro_template_content = '<?php
/*
 * Custom WordPress Template: ' . $template_bits['template_name'] . '
 */
?>
';

			}

			$template_file_name = $template_bits['template_file_name'] == 'a404' ? '404' : $template_bits['template_file_name'];
			$extender_pro_template_content .= $template_bits['template_textarea'];

			$handle = @fopen( extender_pro_get_custom_template_paths( $template_file_name, $template_bits['template_type'] ), 'w+' );
			@fwrite( $handle, htmlspecialchars_decode( stripslashes( $extender_pro_template_content ) ) );
			@fclose( $handle );

			$extender_pro_template_content = '';
			
		}
		
	}
	
}

/**
 * Create the Extender Pro Custom Widget Areas Register file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_widget_areas_register_file() {
	
	if ( file_exists( extender_pro_get_custom_widget_areas_register_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_widget_areas_register_path(), 'w' );
	@fwrite( $handle, stripslashes( '<?php' . "\n" . '/**' . "\n" . ' * Build, Register and Hook-In Custom Widget Areas.' . "\n" . ' *' . "\n" . ' * @package Extender Pro' . "\n" . ' */' . "\n" ) );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Widget Areas Register file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_widget_areas_register( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_widget_areas_register_path() ) )
		extender_pro_create_custom_widget_areas_register_file();

	$handle = @fopen( extender_pro_get_custom_widget_areas_register_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Widget Areas file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_widget_areas_file() {
	
	if ( file_exists( extender_pro_get_custom_widget_areas_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_widget_areas_path(), 'w' );
	@fwrite( $handle, stripslashes( '<?php' . "\n" . '/**' . "\n" . ' * Build, Register and Hook-In Custom Widget Areas.' . "\n" . ' *' . "\n" . ' * @package Extender Pro' . "\n" . ' */' . "\n" ) );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Widget Areas file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_widget_areas( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_widget_areas_path() ) )
		extender_pro_create_custom_widget_areas_file();

	$handle = @fopen( extender_pro_get_custom_widget_areas_path(), 'w+' );
	@fwrite( $handle, stripslashes( $code ) );
	@fclose( $handle );
	
}

/**
 * Create the Extender Pro Custom Hook Boxes file if it does not already exist.
 *
 * @since 1.0.0
 *
 */
function extender_pro_create_custom_hook_boxes_file() {
	
	if ( file_exists( extender_pro_get_custom_hook_boxes_path() ) )
		return;
		
	$handle = @fopen( extender_pro_get_custom_hook_boxes_path(), 'w' );
	@fwrite( $handle, stripslashes( '<?php' . "\n" . '/**' . "\n" . ' * Build and Hook-In Custom Hook Boxes.' . "\n" . ' *' . "\n" . ' * @package Extender Pro' . "\n" . ' */' . "\n" ) );
	@fclose( $handle );
	
}

/**
 * Write to the Extender Pro Custom Hook Boxes file if it exists.
 *
 * @since 1.0.0
 *
 */
function extender_pro_write_custom_hook_boxes( $code = '' ) {
	
	if ( ! file_exists( extender_pro_get_custom_hook_boxes_path() ) )
		extender_pro_create_custom_hook_boxes_file();

	$handle = @fopen( extender_pro_get_custom_hook_boxes_path(), 'w+' );
	@fwrite( $handle, htmlspecialchars_decode( stripslashes( $code ) ) );
	@fclose( $handle );
	
}

/**
 * Call to all necessary functions to create both the
 * Extender Pro and Custom stylesheets.
 *
 * @since 1.0.0
 */
function extender_pro_write_files( $css = true, $custom = true ) {
	
	if ( $css ) {
		
		extender_pro_write_custom_styles();
		extender_pro_write_minified_styles();
		
	}
	
	if ( $custom ) {
		
		extender_pro_write_custom_functions( get_option( extender_pro_theme_option_name( 'custom_functions' ) ) );
		extender_pro_write_custom_frontend_functions( get_option( extender_pro_theme_option_name( 'custom_frontend_functions' ) ) );
		extender_pro_write_custom_header_scripts( get_option( extender_pro_theme_option_name( 'custom_header_scripts' ) ) );
		extender_pro_write_custom_minified_header_scripts( get_option( extender_pro_theme_option_name( 'custom_header_scripts' ) ) );
		extender_pro_write_custom_footer_scripts( get_option( extender_pro_theme_option_name( 'custom_footer_scripts' ) ) );
		extender_pro_write_custom_minified_footer_scripts( get_option( extender_pro_theme_option_name( 'custom_footer_scripts' ) ) );
		extender_pro_write_custom_templates();
		extender_pro_write_custom_widget_areas_register( extender_pro_register_widget_areas() );
		extender_pro_write_custom_widget_areas( extender_pro_build_widget_areas() );
		extender_pro_write_custom_hook_boxes( extender_pro_build_hook_boxes() );
		
	}
	
}
