<?php
/**
 * This is the initialization file for Extender Pro,
 * defining constants, globaling database option arrays
 * and requiring other function files.
 *
 * @package Extender Pro
 */

require_once( EXTPRO_DIR . 'lib/functions/add-styles.php' );
require_once( EXTPRO_DIR . 'lib/functions/general.php' );

/**
 * Require files only needed for admin.
 */
if ( is_admin() ) {
	
	require_once( EXTPRO_DIR . 'lib/functions/option-lists.php' );
	require_once( EXTPRO_DIR . 'lib/admin/build-menu.php' );
	require_once( EXTPRO_DIR . 'lib/admin/settings.php' );
	require_once( EXTPRO_DIR . 'lib/admin/custom-options.php' );
	require_once( EXTPRO_DIR . 'lib/admin/bulletproof/bulletproof.php' );
	require_once( EXTPRO_DIR . 'lib/admin/image-manager-options.php' );
	require_once( EXTPRO_DIR . 'lib/admin/import-export-options.php' );
	require_once( EXTPRO_DIR . 'lib/functions/write-files.php' );
	require_once( EXTPRO_DIR . 'lib/admin/update/edd-updater.php' );
	require_once( EXTPRO_DIR . 'lib/functions/import-export.php' );
	require_once( EXTPRO_DIR . 'lib/admin/metaboxes.php' );
	require_once( EXTPRO_DIR . 'lib/functions/templates.php' );
	require_once( EXTPRO_DIR . 'lib/functions/labels.php' );
	require_once( EXTPRO_DIR . 'lib/functions/conditionals.php' );
	require_once( EXTPRO_DIR . 'lib/functions/widget-areas.php' );
	require_once( EXTPRO_DIR . 'lib/functions/hook-boxes.php' );
	require_once( EXTPRO_DIR . 'lib/admin/update/update.php' );
	
}

add_action( 'init', 'extender_pro_frontend_dev_tools_init' );
/**
 * Conditionally initialize the frontend dev tools.
 *
 * @since 1.0.0
 */
function extender_pro_frontend_dev_tools_init() {
	
	if ( ! current_user_can( 'administrator' ) )
		return;

	if ( extender_pro_get_settings( 'enable_frontend_dev_tools' ) && ! is_admin() )
		require_once( EXTPRO_DIR . 'lib/functions/fe-dev-tools.php' );
		
	if ( extender_pro_get_settings( 'enable_frontend_dev_tools' ) ) {
		
		add_action( 'wp_ajax_extender_pro_style_editor_save', 'extender_pro_style_editor_save' );
		/**
		 * Use ajax to update the theme styles based on the posted values.
		 *
		 * @since 1.0.0
		 */
		function extender_pro_style_editor_save() {
			
			check_ajax_referer( 'extender-pro-ajax-nonce', 'security' );
			update_option( extender_pro_theme_option_name( 'custom_styles' ), $_POST['extender']['custom_styles'] );
			extender_pro_write_files( $css = true, $custom = false  );
			
			echo 'Saved!';
			exit();
			
		}
		
	}
		
	if ( PHP_VERSION >= 5.3 && extender_pro_get_settings( 'enable_frontend_hooks_map' ) )
		require_once( EXTPRO_DIR . 'lib/functions/hooks-map.php' );
		
}

// Require the Cobalt Apps Admin Bar Menu code.
require_once( EXTPRO_DIR . 'lib/functions/admin-bar-menu.php' );
